_positive = set(
    [
        "abba",
        "abilitate",
        "NO TRANSLATION",
        "absolut",
        "iertare",
        "absorbită",
        "abundent",
        "academic",
        "academie",
        "acceptabil",
        "acceptare",
        "accesibil",
        "acoladă",
        "cazare",
        "acompaniament",
        "realiza",
        "realizat",
        "realizare",
        "acord",
        "responsabilitate",
        "responsabil",
        "acreditat",
        "NO TRANSLATION",
        "precis",
        "as",
        "obține",
        "realizare",
        "confirmare",
        "dobândi",
        "dobândirea",
        "acrobat",
        "acțiune",
        "real",
        "acuitate",
        "pătrundere",
        "adapta",
        "adaptabil",
        "adrese",
        "expert",
        "NO TRANSLATION",
        "adjunct",
        "admirabil",
        "amiral",
        "admirație",
        "admira",
        "admirator",
        "admisibil",
        "adorabil",
        "adorare",
        "adora",
        "avans",
        "avansat",
        "avansare",
        "avantaj",
        "avantajos",
        "venire",
        "aventură",
        "aventuros",
        "recomandabil",
        "recomanda",
        "consilier",
        "susținere",
        "estetic",
        "estetică",
        "afabil",
        "afecţiune",
        "afiliat",
        "afirma",
        "afirmare",
        "afirmativ",
        "afirmativ",
        "afluență",
        "afluent",
        "permite",
        "NO TRANSLATION",
        "agil",
        "agilitate",
        "de acord",
        "agreabil",
        "de acord",
        "fiind de acord",
        "acord",
        "agricultură",
        "înainte",
        "ajutor",
        "complicitatea",
        "alabastru",
        "vigilenţă",
        "NO TRANSLATION",
        "în viaţă",
        "domoli",
        "credință",
        "allegro",
        "atenua",
        "alinare",
        "aliat",
        "admisibil",
        "momi",
        "ademenitor",
        "aliat",
        "atotputernic",
        "aloha",
        "uimitor",
        "ambasador",
        "ambiţie",
        "ameliora",
        "Amin",
        "maleabil",
        "modifica",
        "compensație",
        "amenitate",
        "amabil",
        "amical",
        "amnistia",
        "NO TRANSLATION",
        "amuza",
        "amuzat",
        "amuzament",
        "amuzant",
        "analist",
        "ancoră",
        "ancorare",
        "înger",
        "angelic",
        "anima",
        "animat",
        "antibiotice",
        "antidot",
        "antifungic",
        "antic",
        "antiseptic",
        "aplomb",
        "apologetic",
        "scuza",
        "apologie",
        "apostol",
        "aplauze",
        "apreciere",
        "aprobare",
        "aprobare",
        "aproba",
        "pentru aprobarea",
        "potrivit",
        "aptitudine",
        "arheologie",
        "înflăcărat",
        "ardoare",
        "aristocraţie",
        "aristocratic",
        "armură",
        "aromă",
        "trezi",
        "mulțime",
        "artă",
        "articulat",
        "articulare",
        "artizan",
        "NO TRANSLATION",
        "artistic",
        "ascendent",
        "ascensiune",
        "aspiraţie",
        "aspira",
        "aspirant",
        "asamblare",
        "consimțământ",
        "afirmând",
        "bunuri",
        "asista",
        "asistenţă",
        "asociat",
        "domoli",
        "asigurare",
        "asigurat",
        "NO TRANSLATION",
        "uimire",
        "astrolog",
        "astronaut",
        "astronom",
        "pătrunzător",
        "atlet",
        "atletic",
        "atom",
        "ispăşi",
        "ispăşire",
        "atașament",
        "accesibil",
        "realizare",
        "însoţitor",
        "Atenţie",
        "atent",
        "atesta",
        "avocat",
        "atracţie",
        "atracție",
        "mări",
        "August",
        "mătuşă",
        "aură",
        "de bun augur",
        "autentic",
        "autenticitate",
        "autor",
        "autoritar",
        "autoritate",
        "autorizare",
        "autorizat",
        "Avatar",
        "adjudecare",
        "Ay",
        "Aye",
        "bebelus",
        "bacalaureat",
        "șira spinării",
        "echilibru",
        "echilibrat",
        "baladă",
        "balet",
        "vot",
        "balsam",
        "banchet",
        "botez",
        "botez",
        "bard",
        "afacere",
        "baschet",
        "bastion",
        "baie",
        "grindă",
        "radios",
        "înfrumuseţare",
        "frumoasa",
        "înfrumuseţa",
        "frumuseţe",
        "roca de bază",
        "bere",
        "care stă bine",
        "ocroti",
        "credincios",
        "binefăcător",
        "benefice",
        "beneficiu",
        "bunăvoinţă",
        "benign",
        "dană",
        "logodit",
        "îmbunătățire",
        "băutură",
        "biblic",
        "bilingv",
        "naștere",
        "zi de nastere",
        "ireproșabil",
        "binecuvânta",
        "binecuvântat",
        "binecuvântare",
        "binecuvântări",
        "fericire",
        "beatifică",
        "fără vlagă",
        "a inflori",
        "inflori",
        "Gardă personală",
        "îndrăzneţ",
        "îndrăzneală",
        "susţine",
        "noroc neașteptat",
        "NO TRANSLATION",
        "primă",
        "livresc",
        "librărie",
        "avantaj",
        "darnic",
        "milostivire",
        "buchet",
        "creier",
        "vitejie",
        "mic dejun",
        "de mireasă",
        "mireasă",
        "mire",
        "domnișoară de onoare",
        "lumina",
        "strălucire",
        "Sclipitor",
        "brocart",
        "frate",
        "fraternitate",
        "frățesc",
        "amice",
        "construi",
        "clădire",
        "buldog",
        "anti-glont",
        "geamandură",
        "guriță",
        "majordom",
        "untos",
        "plină de viaţă",
        "bâzâit",
        "taxi",
        "cabinet",
        "cafenea",
        "calculator",
        "vițel",
        "calm",
        "canar",
        "sincer",
        "candidat",
        "zaharisit",
        "capitalist",
        "căpitan",
        "captiva",
        "captivant",
        "Carieră",
        "atent",
        "cu grija",
        "mângâiere",
        "îngrijitor",
        "colinda",
        "cascadă",
        "bani gheata",
        "categoric",
        "satisface",
        "cathartic",
        "catedrală",
        "precaut",
        "precaut",
        "celebru",
        "sărbătorind",
        "celebrare",
        "ceresc",
        "centru",
        "centurion",
        "cerebral",
        "ceremonie",
        "certitudine",
        "preşedinte",
        "președintă",
        "campion",
        "psalmodiere",
        "încărcător",
        "caritabil",
        "caritate",
        "farmec",
        "fermecător",
        "castitate",
        "limbuție",
        "Lista de verificare",
        "ridica moralul",
        "bine dispus",
        "Veselie",
        "aplauze",
        "NO TRANSLATION",
        "chimist",
        "nutri",
        "cireașă",
        "șef de trib",
        "copil",
        "copilărie",
        "ciripit",
        "daltă",
        "cavalerime",
        "ciocolată",
        "alegere",
        "cor",
        "coral",
        "cor",
        "ales",
        "Chowder",
        "cronică",
        "chicoteală",
        "biserică",
        "cidru",
        "circumcizie",
        "cetăţean",
        "civil",
        "politeţe",
        "civilizaţie",
        "civilizat",
        "clarvăzător",
        "bate",
        "clarifica",
        "clasic",
        "clasic",
        "clasice",
        "clasifica",
        "curat",
        "curățenie",
        "curăţenie",
        "curat",
        "curăța",
        "curățare",
        "degajare",
        "claritate",
        "clerical",
        "inteligent",
        "deșteptăciune",
        "punct culminant",
        "apropiere",
        "închidere",
        "NO TRANSLATION",
        "clovn",
        "coaliţie",
        "coastă",
        "coexista",
        "convingător",
        "cognitiv",
        "coerenţă",
        "coerent",
        "coeziv",
        "în colectiv",
        "colonel",
        "colosal",
        "confort",
        "comandant",
        "impunător",
        "comemora",
        "comemorare",
        "comemorativ",
        "recomanda",
        "lăudabil",
        "comentator",
        "comise",
        "comodor",
        "comunitate de națiuni",
        "comunica",
        "comunicativ",
        "comuniune",
        "comunitate",
        "comutare",
        "naveta",
        "companion",
        "compasiune",
        "Milos",
        "compatibilitate",
        "compatibil",
        "convingătoare",
        "compensa",
        "compensatorie",
        "competență",
        "competență",
        "competent",
        "automulțumire",
        "completa",
        "complementar",
        "complet",
        "deplinătate",
        "completarea",
        "completare",
        "conformitate",
        "conforme",
        "NO TRANSLATION",
        "compusă",
        "compozitor",
        "calm",
        "înţelege",
        "cuprinzător",
        "camarad",
        "concentric",
        "conciliere",
        "de încheiere",
        "concordie",
        "concordanţă",
        "condoleanţe",
        "scuza",
        "favorabile",
        "conductibilitate",
        "confederat",
        "încredere",
        "încrezător",
        "confirmat",
        "conformitate",
        "simpatic",
        "de felicitare",
        "congregaţie",
        "congruenţă",
        "cunoscător",
        "conştiinţă",
        "conștiincios",
        "constiinta",
        "consacrare",
        "conservare",
        "conserva",
        "considerabil",
        "grijuliu",
        "consistență",
        "consolă",
        "consoană",
        "constanţă",
        "constant",
        "constituţional",
        "construi",
        "desăvârşit",
        "a lua legatura",
        "contemplare",
        "conţinut",
        "continua",
        "contur",
        "a contribui",
        "colaborator",
        "comoditate",
        "convenabil",
        "mănăstire",
        "convenţie",
        "cunoscător în",
        "de conversaţie",
        "convertit",
        "convinge",
        "misto",
        "răcoare",
        "coopera",
        "cooperant",
        "cooperare",
        "de cooperare",
        "miez",
        "încoronare",
        "corporație",
        "corporal",
        "corectiv",
        "corespondenţă",
        "corobora",
        "cosmopolit",
        "confortabil",
        "consiliu",
        "sfat",
        "consilier",
        "numara",
        "contesă",
        "curaj",
        "curajos",
        "politicos",
        "curtoazie",
        "curte",
        "golfuleţ",
        "legământ",
        "leagăn",
        "ambarcațiune",
        "artizan",
        "cremă",
        "crea",
        "creator",
        "crezare",
        "acreditărilor",
        "credibilitate",
        "credibil",
        "credit",
        "NO TRANSLATION",
        "creditate",
        "crescendo",
        "critică",
        "încoronare",
        "crucial",
        "cristal",
        "îmbrățișa",
        "culinar",
        "culminare",
        "cultiva",
        "cultivat",
        "cultivare",
        "cultură",
        "vindecabil",
        "curiozitate",
        "răsuci",
        "amortiza",
        "client",
        "drăguţ",
        "tăietori",
        "doamnă",
        "dans",
        "îndrăzneț",
        "dragă",
        "elegant",
        "fiică",
        "zori de zi",
        "afacere",
        "dragă",
        "dezbate",
        "decenţă",
        "decent",
        "declarativ",
        "dedicare",
        "apăra",
        "apărat",
        "apărător",
        "apărarea",
        "apărare",
        "deferenţă",
        "definitiv",
        "grad",
        "delectable",
        "delega",
        "delibera",
        "delicios",
        "încântare",
        "Încântat",
        "încântător",
        "eliberare",
        "livrare",
        "democraţie",
        "demonstrabil",
        "demonstrativ",
        "adâncime",
        "descriptiv",
        "merita",
        "meritat",
        "proiectant",
        "de dorit",
        "dorind",
        "doritor",
        "destinaţie",
        "detecta",
        "detectare",
        "determinare",
        "determinat",
        "dezvolta",
        "evlavios",
        "pios",
        "dexteritate",
        "diamant",
        "jurnal",
        "dicţionar",
        "didactic",
        "dietetic",
        "demn",
        "demnitate",
        "diligență",
        "cină",
        "diplomaţie",
        "diplomatic",
        "director",
        "descoperire",
        "NO TRANSLATION",
        "discreție",
        "discreționar",
        "discuţie",
        "dezinfectare",
        "dispuse",
        "difuza",
        "distilare",
        "distincţie",
        "cântec",
        "diversificat",
        "deviere",
        "divinitate",
        "doctor",
        "făcător",
        "perseverent",
        "delfin",
        "don",
        "donare",
        "fără îndoială",
        "porumbel",
        "pufos",
        "duet",
        "duce",
        "durabilitate",
        "durabil",
        "cuminte",
        "dornic",
        "aviditate",
        "conte englez",
        "câştiga",
        "zelos",
        "serios",
        "seriozitate",
        "uşura",
        "servitute",
        "NO TRANSLATION",
        "mânca",
        "extaz",
        "extatic",
        "zidire",
        "educa",
        "educat",
        "educational",
        "efectiv",
        "eficacitate",
        "eficienţă",
        "eficient",
        "efort",
        "ejaculare",
        "elaborare",
        "entuziasmat",
        "mai mare",
        "bătrâni",
        "alege",
        "electric",
        "electricitate",
        "eleganţă",
        "elegant",
        "elevație",
        "eligibil",
        "elită",
        "elocvenţă",
        "elocvent",
        "elucida",
        "emancipare",
        "îmbrăţişare",
        "emerit",
        "eminenţă",
        "eminent",
        "eminamente",
        "NO TRANSLATION",
        "empatie",
        "împuternici",
        "emula",
        "permite",
        "imputernicirea",
        "încânta",
        "fermecat",
        "feeric",
        "NO TRANSLATION",
        "a incuraja",
        "încurajare",
        "enciclopedie",
        "efort",
        "înzestra",
        "înzestrat",
        "dotare",
        "rezistență",
        "îndura",
        "energic",
        "angajat",
        "captivant",
        "spori",
        "se bucura",
        "se bucură",
        "lumina",
        "iluminism",
        "anima",
        "îmbogăţi",
        "ansamblu",
        "stegar",
        "întreprinzător",
        "distra",
        "distrați",
        "distractiv",
        "divertisment",
        "entuziasm",
        "entuziast",
        "NO TRANSLATION",
        "efemeridelor",
        "epic",
        "rezumat",
        "egalitate",
        "in aceeasi masura",
        "echilibru",
        "capitaluri proprii",
        "misiune",
        "erudit",
        "spirit",
        "esenţial",
        "stabilit",
        "stima",
        "estetic",
        "etic",
        "etică",
        "vesnic verde",
        "veșnic",
        "evident",
        "evoluţie",
        "înălţa",
        "exaltare",
        "exaltat",
        "depăși",
        "excela",
        "excelență",
        "excelent",
        "schimb valutar",
        "excitabil",
        "excitaţie",
        "excita",
        "excitat",
        "entuziasm",
        "emoționant",
        "exemplar",
        "scutire",
        "bucurie",
        "îndemna",
        "îndemnare",
        "existenţă",
        "exotic",
        "aştepta",
        "așteptare",
        "expedient",
        "expediție",
        "cu experienta",
        "expert",
        "expertiză",
        "explica",
        "rafinat",
        "minunat",
        "extinde",
        "extensiv",
        "suplimentar",
        "extraordinar",
        "degaja",
        "exuberanţă",
        "facilita",
        "fapte",
        "facultate",
        "NO TRANSLATION",
        "echitabil",
        "destul de",
        "credinţă",
        "credincios",
        "faimă",
        "familiar",
        "familiaritate",
        "celebru",
        "faimos",
        "extravagant",
        "fanfară",
        "fascinant",
        "farmec",
        "la modă",
        "fără cusur",
        "favorabil",
        "favorit",
        "favoritism",
        "neînfricat",
        "ispravă",
        "caracteristică",
        "fericire",
        "coleg",
        "tovărășie",
        "Femeie",
        "fertil",
        "fervoare",
        "festival",
        "festiv",
        "NO TRANSLATION",
        "fidelitate",
        "petrecere",
        "in cele din urma",
        "podoabe",
        "fineţe",
        "bolid",
        "ignifug",
        "fermitate",
        "NO TRANSLATION",
        "montaj",
        "accesoriu",
        "măgulitor",
        "flota",
        "flexibilitate",
        "floral",
        "curgere",
        "înflorit",
        "culoare",
        "zbor",
        "concentra",
        "duioșie",
        "alimente",
        "fotbal",
        "toleranţă",
        "proră",
        "străbun",
        "anterior",
        "maistru",
        "precursor",
        "prevedea",
        "prevăzută",
        "previziune",
        "forja",
        "iartă",
        "iertat",
        "iertător",
        "formativă",
        "formulă",
        "NO TRANSLATION",
        "viitor",
        "fortifica",
        "curaj",
        "fortăreață",
        "norocos",
        "avere",
        "redirecţiona",
        "găsite",
        "fundație",
        "aromat",
        "sincer",
        "sinceritate",
        "fratern",
        "libertate",
        "în mod liber",
        "prieten",
        "prietenie",
        "prietenos",
        "prietenie",
        "zburdalnic",
        "zburda",
        "frugal",
        "roditor",
        "îndeplini",
        "împlinire",
        "deplin",
        "complet",
        "distracţie",
        "fundamental",
        "siguranță",
        "fuziune",
        "câştig",
        "câștigând",
        "galant",
        "bravură",
        "belşug",
        "grădină",
        "granat",
        "garnizoană",
        "gazetă",
        "Angrenaj",
        "bijuterie",
        "general",
        "generozitate",
        "generos",
        "bonom",
        "geniu",
        "binevoitor",
        "domn",
        "blândeţe",
        "mică nobilime",
        "autentic",
        "geranium",
        "cadou",
        "talentat",
        "gigantic",
        "chicoti",
        "grindă",
        "oferindu-",
        "bucuros",
        "bucurie",
        "bucurie",
        "alunecare",
        "licărire",
        "scânteietor",
        "glorificare",
        "glorifica",
        "glorie",
        "luciu",
        "strălucire",
        "aprins",
        "dumnezeu",
        "evlavios",
        "chilipir",
        "aur",
        "bun",
        "frumos",
        "bunătate",
        "bunuri",
        "bunăvoință",
        "splendid",
        "Evanghelie",
        "guverna",
        "graţie",
        "graţios",
        "îndurător",
        "grațios",
        "absolvire",
        "nepoți",
        "grandoare",
        "bunică",
        "acorda",
        "acordat",
        "recunoscător",
        "satisface",
        "recunoștință",
        "mai mare",
        "măreţie",
        "verde",
        "Salut",
        "gregar",
        "grimasă",
        "şrot",
        "pietriș",
        "terasament",
        "crește",
        "creştere",
        "garanție",
        "pază",
        "paznic",
        "tutelă",
        "de guvernator",
        "îndrumare",
        "ghid",
        "ghid",
        "guru",
        "burtă",
        "gimnast",
        "habitat",
        "sănătos",
        "la indemana",
        "fericit",
        "fericire",
        "fericit",
        "rezistent",
        "armonios",
        "armonie",
        "recolta",
        "refugiu",
        "progres",
        "vindeca",
        "cicatrizare",
        "sănătos",
        "sănătos",
        "cordial",
        "vatră",
        "din toată inima",
        "ceresc",
        "ceruri",
        "ridicare",
        "cască",
        "ajutor",
        "util",
        "pe bază de plante",
        "erou",
        "eroic",
        "eroisme",
        "eroină",
        "eroism",
        "tinerețe",
        "vesel",
        "ilaritate",
        "închiriere",
        "pasiune",
        "vacanţă",
        "sfinţenie",
        "sfânt",
        "omagiu",
        "omologie",
        "sincer",
        "onestitate",
        "Miere",
        "lună de miere",
        "onora",
        "onorabil",
        "speranţă",
        "plin de speranță",
        "orizont",
        "ospitalitate",
        "gospodărie",
        "menaj",
        "îmbrăţişare",
        "uman",
        "umanitar",
        "umanitate",
        "umiliți",
        "cu umilinţă",
        "umilinţă",
        "umorist",
        "plin de umor",
        "Ura",
        "creştere",
        "tăcere",
        "colibă",
        "igienic",
        "imn",
        "idealism",
        "idol",
        "NO TRANSLATION",
        "lumină",
        "ilustra",
        "ilustru",
        "imaginativ",
        "imaculat",
        "imens",
        "cufunda",
        "nemuritor",
        "împărtăși",
        "imparţial",
        "imparţialitate",
        "impecabil",
        "impermeabil",
        "importanţă",
        "important",
        "impresiona",
        "impresie",
        "îmbunătăţi",
        "îmbunătățit",
        "îmbunătăţire",
        "îmbunătățirea",
        "improviza",
        "inalienabil",
        "inaugurare",
        "incisiv",
        "include",
        "inclus",
        "inclusiv",
        "inclusiv",
        "crește",
        "indelebilă",
        "despăgubire",
        "independenţă",
        "indestructibil",
        "individualitate",
        "îndărătnic",
        "inefabil",
        "ieftin",
        "infailibil",
        "copil",
        "infinit",
        "infinit",
        "influent",
        "informație",
        "ingenios",
        "moştenire",
        "inimitabil",
        "nevinovăţie",
        "nevinovat",
        "inocență",
        "inofensiv",
        "inova",
        "inovaţie",
        "solicitator",
        "Anchetă",
        "indiscret",
        "de nedespartit",
        "însemn",
        "inspector",
        "inspirație",
        "a inspira",
        "inspirat",
        "instinctiv",
        "instrui",
        "instrucție",
        "instructor",
        "instrumental",
        "asigura",
        "intact",
        "integritate",
        "intelect",
        "intelectual",
        "inteligență",
        "inteligent",
        "destinate",
        "relaţii sexuale",
        "interes",
        "interesat",
        "interesant",
        "interior",
        "interlocutorie",
        "interludiu",
        "intim",
        "intonaţie",
        "cutezător",
        "intuiţie",
        "intuitiv",
        "invariabil",
        "inventiv",
        "inventator",
        "investiga",
        "înviora",
        "invitație",
        "a invita",
        "îmbietor",
        "fier",
        "ireductibil",
        "irefutabile",
        "potul cel mare",
        "gem",
        "NO TRANSLATION",
        "loc de munca",
        "a adera",
        "alăturat",
        "mucalit",
        "glumind",
        "ziarist",
        "călătorie",
        "jovial",
        "bucurie",
        "vesel",
        "vesel",
        "triumfător",
        "jubileu",
        "judiciar",
        "judicios",
        "a sari",
        "justiţie",
        "justificabil",
        "justificare",
        "suvenir",
        "orizont",
        "keynote",
        "trapezului",
        "drăguț",
        "bunătate",
        "înrudire",
        "rege",
        "pup",
        "pisoi",
        "talent",
        "cavaler",
        "cunoaștere",
        "cunoştinţe",
        "Kudos",
        "muncă",
        "miel",
        "teren",
        "a aterizat",
        "cu laser",
        "lăudabil",
        "a rade",
        "razand",
        "râsete",
        "lansa",
        "laureat",
        "dafin",
        "laur",
        "generos",
        "legal",
        "conduce",
        "lider",
        "ligă",
        "învăța",
        "învăţare",
        "lector",
        "derivă",
        "legal",
        "legalizat",
        "legendar",
        "lizibilitate",
        "lizibil",
        "timp liber",
        "pe îndelete",
        "lemă",
        "îngăduitor",
        "lecţie",
        "știutor de carte",
        "nivel",
        "pârghie",
        "elibera",
        "eliberare",
        "libertate",
        "bibliotecă",
        "seva",
        "far",
        "simpatie",
        "lingvist",
        "leu",
        "sprinten",
        "logic",
        "longevitate",
        "calitatea de lord",
        "amabil",
        "dragoste",
        "minunat",
        "NO TRANSLATION",
        "amant",
        "iubitor",
        "loial",
        "loialitate",
        "noroc",
        "norocos",
        "delicios",
        "luciu",
        "lucios",
        "luxuriant",
        "luxos",
        "luxos",
        "liră",
        "liric",
        "magic",
        "magnet",
        "magnetism",
        "magnetit",
        "splendoare",
        "magnific",
        "de fată",
        "principal",
        "sprijin temeinic",
        "maiestuos",
        "maiestate",
        "major",
        "majoritate",
        "administra",
        "administrare",
        "mandarin",
        "bărbăție",
        "manifestat",
        "bărbătesc",
        "mană",
        "manierat",
        "maniere",
        "producător",
        "Martie",
        "marcat",
        "vandabil",
        "marchiz",
        "căsătorie",
        "măduvă",
        "căsători",
        "mareșal",
        "minune",
        "minunat",
        "în chip minunat",
        "masculin",
        "masaj",
        "maestru",
        "capodopera",
        "măiestrie",
        "pereche",
        "căsătorie",
        "matroană",
        "maxim",
        "primar",
        "luncă",
        "măsurat",
        "medalie",
        "media",
        "mediere",
        "mediator",
        "medical",
        "NO TRANSLATION",
        "Mediterana",
        "potpuriu",
        "memento",
        "memorabil",
        "lucrări de reparare",
        "menstruaţie",
        "mentor",
        "milostiv",
        "milă",
        "îmbina",
        "merit",
        "meritoriu",
        "veselie",
        "vesel",
        "metropolitan",
        "temperament",
        "microscopie",
        "moșit",
        "puternic",
        "mima",
        "atent",
        "atenție",
        "minister",
        "miracol",
        "miraculos",
        "veselie",
        "misionar",
        "model",
        "moderat",
        "moderator",
        "modest",
        "modestie",
        "impuls",
        "monetar",
        "bani",
        "călugăr",
        "monument",
        "morală",
        "moralitate",
        "morala",
        "mortar",
        "maternitate",
        "motiv",
        "mobil",
        "motor",
        "muscular",
        "muzică",
        "muzical",
        "mutabil",
        "reciproc",
        "pui de somn",
        "naturalist",
        "navigabil",
        "îngrijit",
        "nectar",
        "ac",
        "a negocia",
        "negociator",
        "vecin",
        "nerv",
        "cuibări",
        "nobleţe",
        "nobil",
        "nobil",
        "numire",
        "normalitate",
        "notabil",
        "notabilii",
        "NO TRANSLATION",
        "noţiune",
        "alimentație",
        "numerele",
        "asistent medical",
        "pepinieră",
        "hrăni",
        "hrănitor",
        "stejar",
        "oază",
        "jurământ",
        "ascultare",
        "obiectiv",
        "îndatoritor",
        "atent",
        "care se poate obține",
        "evident",
        "ocupant",
        "ocupaţie",
        "ocupa",
        "oferi",
        "ofiţer",
        "ofset",
        "ramură",
        "omniscient",
        "sinceritate",
        "operă",
        "oportun",
        "oportunitate",
        "optimism",
        "optimist",
        "opțiune",
        "facultativ",
        "oracol",
        "discurs",
        "orchestră",
        "ordinat",
        "ordonat",
        "hirotonisire",
        "organic",
        "organizare",
        "organiza",
        "organizat",
        "orgasm",
        "originalitate",
        "ornamentate",
        "bogat ornamentat",
        "rezultat",
        "se întrece pe sine",
        "exterior",
        "încântat la culme",
        "copleșitor",
        "proprietate",
        "Pacific",
        "tampon",
        "umplutură",
        "paletă",
        "gustos",
        "paliativ",
        "panaceu",
        "pompon",
        "NO TRANSLATION",
        "paprika",
        "model de perfecțiune",
        "suprem",
        "Pardon",
        "ascendență",
        "parietal",
        "lua parte",
        "participare",
        "partener",
        "asociere",
        "pasiune",
        "pasionat",
        "distracţie",
        "pastor",
        "patiserie",
        "păşune",
        "brevet",
        "răbdare",
        "rabdator",
        "patriarhal",
        "patron",
        "patronaj",
        "a plati",
        "pace",
        "iubitor de pace",
        "liniștit",
        "păun",
        "ciuguli",
        "particularitate",
        "genealogie",
        "inegalabil",
        "înclinaţie",
        "percepe",
        "perceptibil",
        "peren",
        "perfect",
        "perfecţiune",
        "interpret",
        "filtra cafea",
        "permisiune",
        "inalienabilitate",
        "persistenţă",
        "persistent",
        "arătos",
        "pertinent",
        "farmaceutic",
        "filantrop",
        "filantropie",
        "filozof",
        "fenix",
        "fonetic",
        "medic",
        "fizică",
        "fiziologie",
        "fizic",
        "alege",
        "picnic",
        "pitoresc",
        "pietate",
        "pilulă",
        "pernă",
        "pilot",
        "belvedere",
        "pionier",
        "pios",
        "măduvă",
        "pivot",
        "liniștit",
        "planificare",
        "jucăuş",
        "loc de joaca",
        "teatru",
        "placut",
        "mulţumit",
        "plăcut",
        "angajament",
        "plenar",
        "abundent",
        "plex",
        "prună",
        "plumb",
        "pluș",
        "strat",
        "ascuțit",
        "politie",
        "polițist",
        "lustrui",
        "lustruit",
        "politicos",
        "politeţe",
        "NO TRANSLATION",
        "piscină",
        "papă",
        "popularitate",
        "popularizat",
        "populație",
        "portabil",
        "poseda",
        "potabil",
        "putere",
        "puternic",
        "cu putere",
        "practică",
        "practicat",
        "practică",
        "laudă",
        "lăudat",
        "lăudabil",
        "ruga",
        "prevedere",
        "preceda",
        "precedenta",
        "prețios",
        "precis",
        "precizie",
        "predilecţie",
        "predominant",
        "preeminent",
        "prefera",
        "premier",
        "sediu",
        "a pregati",
        "pregătit",
        "prescient",
        "prezenţă",
        "prezent",
        "prezentabil",
        "substanță conservantă",
        "conserva",
        "președinte",
        "prestigiu",
        "Presto",
        "frumos",
        "prevala",
        "profilaxie",
        "neprețuit",
        "mândrie",
        "preot",
        "preoţie",
        "preoţesc",
        "întâietate",
        "primar",
        "prim",
        "grund",
        "prinţ",
        "princiar",
        "prinţesă",
        "principal",
        "impecabilă",
        "privilegiat",
        "probitate",
        "procedură",
        "procesiune",
        "Proctor",
        "procura",
        "prodigios",
        "minune",
        "producător",
        "producând",
        "producere",
        "productiv",
        "productivitate",
        "profesie",
        "profesional",
        "Profesor",
        "experiență",
        "expert",
        "cheltuitor",
        "progres",
        "progresie",
        "progresiv",
        "prolific",
        "proeminenţă",
        "vizibil",
        "promisiune",
        "promițător",
        "promovare",
        "sprijini",
        "propriu-zis",
        "profet",
        "profilactic",
        "propoziție",
        "perspectivă",
        "prospera",
        "prosperitate",
        "prosper",
        "proteja",
        "protectoare",
        "de protecţie",
        "protector",
        "mândru",
        "dovedi",
        "proverbial",
        "furniza",
        "furnizarea",
        "prudenţă",
        "prudent",
        "psalm",
        "public",
        "Trage",
        "amvon",
        "punctual",
        "punctualitate",
        "cățeluș",
        "pur",
        "purificare",
        "purifica",
        "purist",
        "puritate",
        "tors",
        "ciudat",
        "calificat",
        "de calificare",
        "căutare",
        "întrebare",
        "vioiciune",
        "static",
        "Liniște",
        "chinină",
        "strălucire",
        "radiant",
        "radia",
        "radio",
        "ocupat",
        "extaz",
        "raţional",
        "cititor",
        "uşor",
        "promptitudine",
        "citind",
        "reafirma",
        "real",
        "motiv",
        "reasigurare",
        "reasigura",
        "rabat",
        "reformare",
        "primit",
        "primire",
        "NO TRANSLATION",
        "răspunde la",
        "recuperare",
        "se propti",
        "recunoscut",
        "recomanda",
        "reconciliere",
        "reconsiderare",
        "reconstrui",
        "reconstrucţie",
        "recorder",
        "recupera",
        "recuperare",
        "agrement",
        "agrement",
        "rectifica",
        "răscumpărare",
        "despăgubire",
        "rafina",
        "rafinament",
        "reforma",
        "reformare",
        "reformator",
        "răcoritor",
        "refurbish",
        "regească",
        "regent",
        "regularitate",
        "reglementa",
        "reabilita",
        "reabilitare",
        "rambursa",
        "rambursare",
        "armare",
        "reintegra",
        "bucura",
        "veselie",
        "întineri",
        "intinerit",
        "relaxare",
        "relevant",
        "fiabilitate",
        "de încredere",
        "încredere",
        "relief",
        "alinarea",
        "reface",
        "remarcabil",
        "NO TRANSLATION",
        "remediu",
        "iertare",
        "remodela",
        "renaştere",
        "face",
        "reînnoire",
        "renova",
        "renovare",
        "renume",
        "renumit",
        "reorganiza",
        "reparaţie",
        "rambursa",
        "pocăi",
        "umple",
        "plin",
        "reporter",
        "repaus",
        "reprezentate",
        "reproducător",
        "cu reputație bună",
        "salvare",
        "rezervă",
        "rezident",
        "elastic",
        "rezistiv",
        "în mod hotărât",
        "resurse",
        "respect",
        "respectabilitate",
        "respectabil",
        "respectuos",
        "respectare",
        "privințe",
        "răgaz",
        "splendid",
        "responsabil",
        "sensibil",
        "odihnă",
        "odihnitor",
        "restituire",
        "reconfortant",
        "restabilirea",
        "reţinere",
        "reluare",
        "retenţie",
        "reuniune",
        "chefui",
        "delectează",
        "omeni",
        "reverenţă",
        "venerabil",
        "reverie",
        "revizui",
        "renaştere",
        "revoluţionar",
        "recompensă",
        "ritm",
        "ritmic",
        "panglică",
        "bogăţie",
        "călăreț",
        "drept",
        "legitim",
        "corect",
        "copt",
        "coace",
        "în creștere",
        "nituire",
        "roadster",
        "robust",
        "stâncă",
        "tijă",
        "rollicking",
        "romantism",
        "romantic",
        "romantism",
        "zburda",
        "înrădăcinat",
        "roz",
        "rota",
        "rutină",
        "drepturi de autor",
        "rubrică",
        "cruțare",
        "sigur",
        "salvgarda",
        "salvie",
        "sfânt",
        "sfânt",
        "salariu",
        "proeminent",
        "salutar",
        "salut",
        "salvare",
        "alifie",
        "samurai",
        "sfințire",
        "sfinţi",
        "sanctuar",
        "sanguin",
        "sanitar",
        "satin",
        "satisfăcător",
        "satisfăcut",
        "Salvați",
        "economie",
        "savoare",
        "cimbru",
        "pricepere",
        "savant",
        "Bursa de studiu",
        "științific",
        "om de stiinta",
        "NO TRANSLATION",
        "scor",
        "scrib",
        "scenariu",
        "scrumptious",
        "sculptură",
        "mare",
        "sigiliu, focă",
        "condimentată",
        "secretariat",
        "vechime in munca",
        "senzaţional",
        "sens",
        "sensibilitate",
        "judicios",
        "senzualitate",
        "senzual",
        "sentimental",
        "sentimentalitate",
        "santinelă",
        "seninătate",
        "predică",
        "ser",
        "fondator",
        "sex",
        "formă",
        "bine proporţionat",
        "acțiune",
        "adăpost",
        "păstor",
        "strălucire",
        "strălucitor",
        "cumpărături",
        "umăr",
        "perspicace",
        "mătase",
        "simplifica",
        "sincer",
        "sinceritate",
        "cânta",
        "unul câte unul",
        "domn",
        "sisterhood",
        "calificat",
        "abil",
        "cer",
        "ardezie",
        "neted",
        "subţire",
        "subţire",
        "zâmbet",
        "zâmbitor",
        "lovit",
        "finete",
        "nechezat",
        "sobrietate",
        "sociabil",
        "consolare",
        "soldat",
        "solid",
        "soliditate",
        "soluţie",
        "solvabilitate",
        "sonar",
        "sonată",
        "sonet",
        "sonor",
        "calma",
        "liniştitor",
        "NO TRANSLATION",
        "soliditate",
        "supă",
        "spa",
        "spațios",
        "spaniel",
        "scânteie",
        "special",
        "NO TRANSLATION",
        "vorbire",
        "rapid",
        "ortografie",
        "condiment",
        "spirit",
        "alcool",
        "splendid",
        "splendoare",
        "sponsor",
        "imaculat",
        "soț",
        "molid",
        "grajd",
        "Staccato",
        "inoxidabil",
        "armăsar",
        "viteaz",
        "rezistență",
        "permanent",
        "stea",
        "lumina stelelor",
        "înstelat",
        "impunător",
        "afirmație",
        "statuie",
        "stare",
        "ferm",
        "statornic",
        "stelar",
        "steward",
        "liniște",
        "magazin",
        "simplu",
        "strategic",
        "strateg",
        "putere",
        "a intari",
        "întărire",
        "frapant",
        "impresionant",
        "tare",
        "structura",
        "crampon",
        "studiu",
        "voinic",
        "sublimare",
        "substanţă",
        "substantiv",
        "a reusi",
        "reușind",
        "succes",
        "de succes",
        "succint",
        "suficienta",
        "zahăr",
        "potrivit",
        "sufocant",
        "soare",
        "însorit",
        "apus de soare",
        "raza de soare",
        "superb",
        "suprauman",
        "superior",
        "superioritate",
        "supraom",
        "superstar",
        "implorare",
        "furnituri",
        "livra",
        "sprijinit",
        "suporter",
        "de sprijin",
        "suprem",
        "suprem",
        "garanţie",
        "presupune",
        "depășind",
        "surprinde",
        "topografie",
        "supravieţui",
        "jura",
        "dulce",
        "dragă",
        "dulceata",
        "dulceaţă",
        "dulciuri",
        "rapid",
        "înot",
        "simbolic",
        "simetric",
        "simetrie",
        "simpatic",
        "simpatie",
        "simfonie",
        "sincroniza",
        "sinergică",
        "sinod",
        "tact",
        "poveste",
        "talent",
        "talisman",
        "vorbi",
        "bronzat",
        "sarcină",
        "gustos",
        "gustos",
        "a preda",
        "profesor",
        "tehnologie",
        "cumpătare",
        "călită",
        "care poate fi apărat",
        "tenace",
        "tenacitate",
        "închiriere",
        "chiriaş",
        "delicat, fraged",
        "sensibilitate",
        "recunoscător",
        "mulțumire",
        "teoretic",
        "terapeutic",
        "terapeutică",
        "NO TRANSLATION",
        "de rasă",
        "grijuliu",
        "chibzuința",
        "cumpătare",
        "fior",
        "emoționant",
        "înfloritor",
        "tron",
        "stârni",
        "Tigla",
        "oportun",
        "beteală",
        "titlu",
        "paine prajita",
        "tolerant",
        "toleranţă",
        "top",
        "rezistență",
        "turn",
        "falnic",
        "tradiţional",
        "liniştit",
        "liniște",
        "transcendenta",
        "transcendental",
        "călător",
        "comoară",
        "copac",
        "turbat",
        "tendinţă",
        "la modă",
        "afluent",
        "Omagiu",
        "trig",
        "triumf",
        "triumfător",
        "trofeu",
        "armistiţiu",
        "ADEVĂRAT",
        "demn de încredere",
        "adevăr",
        "veridicitate",
        "tutelă",
        "tutore",
        "geamăn",
        "sclipire",
        "în cele din urmă",
        "arbitru",
        "unanimitate",
        "unanim",
        "modest",
        "imparțial",
        "incasabil",
        "neîntrerupt",
        "neconstrâns",
        "sublinia",
        "înţelegere",
        "subscrie",
        "indiviza",
        "nemuritor",
        "fără echivoc",
        "desfășura",
        "unificare",
        "uniform",
        "neinfectate",
        "unic",
        "unison",
        "unitar",
        "Unit",
        "unitate",
        "universitate",
        "nelimitat",
        "modest",
        "necontestat",
        "fără putință de tăgadă",
        "neintrebat",
        "nevătămat",
        "altruist",
        "neîntrecut",
        "neclintit",
        "înălţa",
        "vertical",
        "utilitate",
        "introduce",
        "ca de obicei",
        "utilitate",
        "utopic",
        "concediu de odihna",
        "vaccin",
        "viteaz",
        "NO TRANSLATION",
        "valoros",
        "avangardă",
        "înfrânge",
        "catifea",
        "catifelat",
        "venerabil",
        "veneraţie",
        "veridicitate",
        "verde",
        "verificare",
        "verificate",
        "într-adevăr",
        "veritabil",
        "vernal",
        "vervă",
        "veteran",
        "vicar",
        "Victor",
        "victorios",
        "victorie",
        "vigilenţă",
        "vigilent",
        "vigoare",
        "viguros",
        "sătean",
        "răzbunați",
        "justificare",
        "virgin",
        "virginitate",
        "virtute",
        "virtuos",
        "viziune",
        "vizionar",
        "vizita",
        "vizitator",
        "vital",
        "vitalitate",
        "vivace",
        "viu",
        "vocabular",
        "voluntar",
        "voluptos",
        "garanta",
        "jurământ",
        "salarizare",
        "garanție",
        "războinic",
        "câine de pază",
        "vigilent",
        "paznic",
        "rezistent la apă",
        "bogatie",
        "rezistentă la intemperii",
        "a salutat",
        "alb",
        "albeață",
        "sănătos",
        "portiță",
        "pe scară largă",
        "de bunăvoie",
        "bunăvoință",
        "pleașcă",
        "câştigător",
        "câștigător",
        "Câștiguri",
        "fără fir",
        "WIS",
        "înţelepciune",
        "înţelept",
        "spirit",
        "rezista",
        "minte",
        "spiritual",
        "vrăjitor",
        "pântec",
        "minunat",
        "minunat",
        "minunat",
        "cuvânt",
        "lucru",
        "cult",
        "in valoare de",
        "vrednic",
        "WOT",
        "scriitor",
        "tineri",
        "mai tanar",
        "tineret",
        "zel",
        "zelos",
        "vervă",
    ]
)

_negative = set(
    [
        "abandon",
        "abandonat",
        "abandon",
        "răpire",
        "aberant",
        "aberaţie",
        "detesta",
        "respingător",
        "abject",
        "anormal",
        "aboli",
        "desființare",
        "abominabil",
        "scârbă",
        "avorta",
        "intrerupere de sarcina",
        "nereușit",
        "abraziune",
        "abroga",
        "abces",
        "absență",
        "absent",
        "absent",
        "absenteism",
        "absurd",
        "absurditate",
        "abuz",
        "abisal",
        "abis",
        "accident",
        "accidental",
        "blestemat",
        "acuzare",
        "acuzativ",
        "acuzat",
        "acuzator",
        "acuzare",
        "durere",
        "dureros",
        "acid",
        "atacabil",
        "sumator",
        "dependenta",
        "adipos",
        "adjudeca",
        "admonestare",
        "în voia valurilor",
        "alterat",
        "adulter",
        "adversar",
        "advers",
        "adversitate",
        "dezola",
        "bolnav",
        "nenorocire",
        "afront",
        "speriat",
        "Urmări",
        "gust care stăruie",
        "agravată",
        "agravant",
        "agravare",
        "agresiune",
        "agresiv",
        "agresor",
        "înspăimântat",
        "agitat",
        "agitaţie",
        "agonizant",
        "agonie",
        "eşuat",
        "pricinui durere",
        "maladiv",
        "fără rost",
        "ifose",
        "alarma",
        "alarmant",
        "alcoolism",
        "străin",
        "aliena",
        "alienat",
        "alienare",
        "pensia alimentară",
        "afirmaţie",
        "pretinde",
        "departe",
        "altercaţie",
        "ambiguu",
        "ambuscadă",
        "amnezie",
        "amfetamine",
        "Anaconda",
        "anal",
        "anarhism",
        "anarhist",
        "anarhie",
        "anatemă",
        "vechi",
        "furie",
        "anghină",
        "pescuit sportiv",
        "furios",
        "chin",
        "animozitate",
        "dușmănie",
        "anihila",
        "anihilat",
        "anihilare",
        "deranja",
        "supărare",
        "enervant",
        "anula",
        "anulare",
        "anomalie",
        "anonim",
        "antagonism",
        "antagonist",
        "antagonic",
        "antrax",
        "antihrist",
        "antipatie",
        "învechit",
        "antisocial",
        "antiteză",
        "anxietate",
        "nerăbdător",
        "apache",
        "apatic",
        "apatie",
        "păduchele",
        "îngrozitor",
        "apendicită",
        "aprehensiune",
        "receptiv",
        "însușire",
        "arhaic",
        "laborios",
        "argumenta",
        "argument",
        "argumentativ",
        "arid",
        "armamente",
        "trimitere în judecată",
        "arieratelor",
        "arestare",
        "aroganţă",
        "arogant",
        "arsenic",
        "incendiere",
        "artilerie",
        "frasin",
        "ruşinat",
        "cenusa",
        "cur",
        "asalta",
        "atacator",
        "asasin",
        "asasina",
        "asasinat",
        "asalt",
        "Idiotule",
        "greșit",
        "astringent",
        "azil",
        "ateism",
        "ateroscleroza",
        "atroce",
        "atrocitate",
        "atrofie",
        "atac",
        "atacare",
        "atenuat",
        "atenuare",
        "îndrăzneală",
        "auster",
        "austeritate",
        "autocratic",
        "autopsie",
        "avalanşă",
        "avariție",
        "răzbunător",
        "potrivnic",
        "aversiune",
        "evita",
        "evitare",
        "îngrozitor",
        "stângăcie",
        "într-o parte",
        "trăncăneală",
        "murmur",
        "babuin",
        "înapoi",
        "înapoi",
        "gârlă",
        "bacterii",
        "NO TRANSLATION",
        "rău",
        "bursuc",
        "prost",
        "proastă calitate",
        "vechil",
        "momeală",
        "balot",
        "răzor",
        "NO TRANSLATION",
        "bandit",
        "nenorocire",
        "bubuitură",
        "Banger",
        "alunga",
        "alungat",
        "exilare",
        "falimentar",
        "faliment",
        "Banshee",
        "Barb",
        "barbar",
        "barbar",
        "barbarie",
        "latra",
        "barat",
        "sterp",
        "baricadă",
        "barieră",
        "fără bază",
        "Bastard",
        "aluat",
        "ponosita",
        "baterie",
        "luptă",
        "luptat",
        "câmp de luptă",
        "indecență",
        "baionetă",
        "purtător",
        "fiară",
        "câinesc",
        "bătaie",
        "întâmpla",
        "cerși",
        "cerşetor",
        "cerșetorie",
        "Behemoth",
        "obligat față de cineva",
        "întârziat",
        "deprecia",
        "beligerant",
        "curea",
        "bender",
        "indoliate",
        "doliu",
        "bereft",
        "înnebunit",
        "bestial",
        "trăda",
        "trădare",
        "ai grijă",
        "dezorientat",
        "părtinire",
        "părtinitor",
        "ciorovăială",
        "NO TRANSLATION",
        "bigot",
        "bigot",
        "bilă",
        "biopsie",
        "mesteacăn",
        "locul naşterii",
        "căţea",
        "mușca",
        "amar",
        "amărăciune",
        "bizar",
        "negru",
        "blackjack",
        "şantaj",
        "ticăloșie",
        "vină",
        "blând",
        "hulitor",
        "blasfemie",
        "explozie",
        "țipător",
        "trăncănesc",
        "foc",
        "mohorât",
        "sângerare",
        "cusur",
        "pacoste",
        "blighted",
        "ORB",
        "orbit",
        "orbeşte",
        "orbire",
        "bășică",
        "umflat",
        "pată de cerneală",
        "blocadă",
        "vărsare de sânge",
        "setos de sânge",
        "sângeros",
        "pată",
        "suflantă",
        "stinge prin suflare",
        "blues",
        "cacealma",
        "gafă",
        "estompa",
        "in ceata",
        "roși",
        "lăudăros",
        "mlaştină",
        "fals",
        "a fierbe",
        "boilerplate",
        "bombă",
        "bombarda",
        "bombardament",
        "bombardat",
        "robie",
        "obligațiuni",
        "nuu",
        "haple",
        "beție",
        "NO TRANSLATION",
        "plictiseală",
        "plictisitor",
        "debitor",
        "deranja",
        "deranjează",
        "fund",
        "legat",
        "rând",
        "bovin",
        "băiat",
        "boicota",
        "lăudăroșenie",
        "coniac",
        "bravadă",
        "certa",
        "deșănțat",
        "breșă",
        "pană",
        "primejdios",
        "NO TRANSLATION",
        "mită",
        "mită",
        "brigadă",
        "pucioasă",
        "se burzului",
        "campanie de calomnii",
        "se emoţiona",
        "rupt",
        "spart",
        "bordel",
        "zdrobi",
        "dârdoră",
        "brutal",
        "brutalitate",
        "brută",
        "bufet",
        "gândac",
        "NO TRANSLATION",
        "bulbos",
        "bătăuş",
        "vagabond",
        "păcat",
        "împovărător",
        "birocraţie",
        "birocrat",
        "hoț",
        "furt",
        "înmormântare",
        "îngropat",
        "strangula",
        "ars",
        "prins",
        "măcelar",
        "îmbinare",
        "bâzâi",
        "intrigi",
        "cacofonie",
        "mitocan",
        "cadaver",
        "cuşcă",
        "de calculat",
        "NO TRANSLATION",
        "apeluri",
        "agitație",
        "Anulare",
        "cancer",
        "gangrenă",
        "canibal",
        "canibalism",
        "NO TRANSLATION",
        "captiv",
        "captivitate",
        "tâlhar",
        "captură",
        "carcasă",
        "carcinomul",
        "cardiomiopatie",
        "nepăsare",
        "caricatură",
        "carie",
        "măcel",
        "carnal",
        "carnivor",
        "cartel",
        "caz",
        "lădiță",
        "castă",
        "victimă",
        "cataractă",
        "catastrofă",
        "cateter",
        "prudență",
        "ceda",
        "cimitir",
        "cenzura",
        "dezaprobare",
        "CESS",
        "încetare",
        "pleavă",
        "chafing",
        "întrista",
        "provocare",
        "haos",
        "haotic",
        "şaradă",
        "taxabil",
        "urmarire",
        "pedeapsă",
        "flecar",
        "ieftin",
        "trișa",
        "prăjitură cu brânză",
        "Chicane",
        "copilăresc",
        "rece",
        "cloroform",
        "sufoca",
        "holeră",
        "a toca",
        "muncă casnică",
        "cronic",
        "ţigară",
        "gălăgie",
        "ciocnire",
        "discordanță",
        "Gheară",
        "mănăstire",
        "întunecat",
        "nebulozitate",
        "tropăi",
        "neîndemânatic",
        "cocaină",
        "constrânge",
        "constrângere",
        "sicriu",
        "rece",
        "rece",
        "frig",
        "colică",
        "colaps",
        "coliziune",
        "înțelegere secretă",
        "comă",
        "comatos",
        "luptă",
        "combatant",
        "combativ",
        "îngropare",
        "agitaţie",
        "comunism",
        "comunist",
        "competiție",
        "plânge",
        "plângere",
        "complexat",
        "complexitate",
        "complica",
        "complicat",
        "complicaţie",
        "compost",
        "constrângere",
        "obligatoriu",
        "ascunde",
        "ascuns",
        "ascundere",
        "vanitate",
        "încrezut",
        "comoție",
        "condamna",
        "condamnare",
        "condescendent",
        "condescendenţă",
        "mărturisire",
        "limita",
        "limitat",
        "naștere",
        "confisca",
        "confiscare",
        "conflagraţie",
        "conflict",
        "contradictoriu",
        "zăpăci",
        "zăpăcit",
        "confunda",
        "confuzie",
        "congestionare",
        "evocare",
        "cucerire",
        "conspirator",
        "conspira",
        "consternare",
        "constipație",
        "constrânge",
        "constrâns",
        "constrângere",
        "contagiune",
        "contagios",
        "contamina",
        "contaminate",
        "contaminare",
        "dispreţ",
        "vrednic de dispreț",
        "dispreţuitor",
        "litigios",
        "contrabandă",
        "contractat",
        "contrazice",
        "contradicţie",
        "contradictoriu",
        "contrar",
        "în contrast",
        "contraveni",
        "contravenție",
        "controversat",
        "controversă",
        "condamna",
        "condamnare",
        "coteț",
        "copie",
        "imitator",
        "coroner",
        "caporal",
        "cadavru",
        "corecţie",
        "coroziune",
        "corosiv",
        "corupt",
        "otrăvitor",
        "corupţie",
        "tuse",
        "consilier",
        "curgând",
        "râvni",
        "laş",
        "laşitate",
        "fricos",
        "ursuz",
        "sparge",
        "crăpat",
        "cracare",
        "cârcel",
        "înghesuit",
        "manivelă",
        "capricios",
        "rahat",
        "prăbușire",
        "crawl",
        "înnebunită",
        "nebun",
        "scârțâind",
        "creatură",
        "târî",
        "crimă",
        "penal",
        "criminalitate",
        "căciuli",
        "infirm",
        "infirm",
        "criză",
        "crocant",
        "critic",
        "critică",
        "a critica",
        "escroc",
        "cruce",
        "chircit",
        "cruciat",
        "răstignire",
        "brut",
        "crud",
        "crud",
        "cruzime",
        "surpare",
        "ronțăit",
        "cruciadă",
        "zdrobit",
        "zdrobitor",
        "arțăgos",
        "strigăt",
        "plâns",
        "criptă",
        "încornorat",
        "cuc",
        "spicui",
        "culpabilitate",
        "culpabil",
        "inculpat",
        "cult",
        "împovărător",
        "ventuze",
        "javră",
        "blestem",
        "blestemat",
        "blestemare",
        "superficial",
        "tăietor",
        "cutthroat",
        "tăiere",
        "cianură",
        "ciclon",
        "chist",
        "citomegalovirus",
        "dabbling",
        "daemon",
        "zănatic",
        "pumnal",
        "deteriora",
        "daune",
        "La naiba",
        "damnațiune",
        "al naibii",
        "amortizor",
        "mătreaţă",
        "dandy",
        "Pericol",
        "periculos",
        "întuneca",
        "întunecat",
        "întuneric",
        "punctată",
        "mişelesc",
        "ametita",
        "dezactivați",
        "impas",
        "mortal",
        "Surd",
        "moarte",
        "dezgheț",
        "depravare",
        "resturi",
        "creanţă",
        "debitor",
        "descompunere",
        "stricat",
        "decedat",
        "înşelăciune",
        "înşelător",
        "înşela",
        "înșelat",
        "înșelător",
        "înşelăciune",
        "înșelător",
        "declinaţie",
        "declin",
        "în scădere",
        "descompunere",
        "scădea",
        "decrementare",
        "ramolit",
        "bârfi",
        "deduce",
        "defăimare",
        "defăimător",
        "Mod implicit",
        "înfrângere",
        "învins",
        "defect",
        "NO TRANSLATION",
        "defect",
        "fără apărare",
        "amânare",
        "sfidare",
        "sfidător",
        "deficienta",
        "deficit",
        "dezumfla",
        "deflaţie",
        "deforma",
        "deformat",
        "deformare",
        "frauda",
        "defunct",
        "sfida",
        "degenerare",
        "degenera",
        "degradare",
        "degrada",
        "degradant",
        "întârziere",
        "întârziat",
        "vătămător",
        "ștergere",
        "delincvenţă",
        "delincvent",
        "delirant",
        "delir",
        "potop",
        "iluzie",
        "delirante",
        "cerere",
        "cerând",
        "dement",
        "demenţă",
        "deces",
        "demola",
        "demolare",
        "demon",
        "demonic",
        "demoralizat",
        "negare",
        "negat",
        "denunţa",
        "denunţare",
        "nega",
        "negare",
        "dispărut",
        "plecare",
        "dependență",
        "dependenţă",
        "deplorabil",
        "deplora",
        "deporta",
        "deportare",
        "depravat",
        "depravare",
        "deprecia",
        "depreciat",
        "depreciere",
        "deprima",
        "deprimat",
        "deprimant",
        "depresiune",
        "depresiv",
        "privațiune",
        "deranjat",
        "abandonat",
        "bătaie de joc",
        "derogare",
        "peiorativ",
        "profanare",
        "deşert",
        "pustiu",
        "dezertare",
        "se abține",
        "pustiire",
        "disperare",
        "deznădăjduit",
        "disperată",
        "josnic",
        "NO TRANSLATION",
        "despotic",
        "despotism",
        "sărac",
        "distrus",
        "distrugător",
        "distruge",
        "distrugere",
        "distructiv",
        "detaşare",
        "reține",
        "deţinut",
        "detenţie",
        "deteriora",
        "deteriorat",
        "deteriorare",
        "detesta",
        "detona",
        "reduce",
        "detriment",
        "în detrimentul",
        "detritus",
        "devasta",
        "devastator",
        "devastare",
        "diavol",
        "diavolesc",
        "întortocheat",
        "transfer",
        "devora",
        "diabolic",
        "diagnostic",
        "diatribă",
        "dictator",
        "dictatorial",
        "dictatură",
        "NO TRANSLATION",
        "dificultăți",
        "dificultate",
        "face o digresiune",
        "dărăpănat",
        "dilua",
        "diminua",
        "diminuat",
        "NO TRANSLATION",
        "NO TRANSLATION",
        "murdărie",
        "murdar",
        "incapacitate",
        "dezactivați",
        "invalid",
        "nemulţumit",
        "dezacord",
        "dezacord",
        "dezacord",
        "nepermis",
        "dezamăgi",
        "dezamăgit",
        "dezamăgitor",
        "dezamăgire",
        "dezaprobare",
        "dezaproba",
        "respins",
        "dezaprobator",
        "dezastru",
        "dezastruos",
        "nu crede",
        "aruncate înapoi în mare",
        "descărcare",
        "disciplina",
        "repudia",
        "modificări de culoare",
        "decolorat",
        "disconfort",
        "deconecta",
        "decuplat",
        "deconectare",
        "nemulţumire",
        "întrerupe",
        "discontinuitate",
        "discordie",
        "descuraja",
        "descurajare",
        "discredita",
        "deosebi",
        "discriminatoriu",
        "discriminare",
        "dispreț",
        "boală",
        "bolnav",
        "fără trup",
        "eliberare",
        "desfigurat",
        "ruşine",
        "NO TRANSLATION",
        "ruşinos",
        "nemulţumit",
        "dezgust",
        "dezgustător",
        "abătut",
        "deprimant",
        "necinstit",
        "necinste",
        "dezonoare",
        "deziluzie",
        "dezinformare",
        "necinstit",
        "dezintegra",
        "dezintegrare",
        "dezinteresat",
        "nu-i plăcea",
        "disliked",
        "dislocat",
        "sumbru",
        "spaimă",
        "dezmembrare",
        "concediere",
        "nesupunere",
        "neascultător",
        "nu se supune",
        "tulburare",
        "dezordonat",
        "dezorganizat",
        "discredita",
        "peiorativ",
        "disparitate",
        "imparțial",
        "risipi",
        "dispersare",
        "deplasa",
        "nemulțumit",
        "neplăcere",
        "dispoziție",
        "deposedați",
        "disputa",
        "descalificare",
        "descalificat",
        "descalifica",
        "nepăsare",
        "ignorate",
        "infamant",
        "lipsă de respect",
        "nerespectuos",
        "perturbare",
        "nemulţumire",
        "disensiune",
        "disident",
        "deserviciu",
        "disident",
        "dizolvare",
        "disonanţă",
        "dezgust",
        "dezagreabil",
        "deformat",
        "deformare",
        "distrage",
        "zăpăcit",
        "distrage atenția",
        "distracție",
        "aiurit",
        "suferință",
        "distressed",
        "dureros",
        "neîncredere",
        "tulburare",
        "deranjat",
        "neîntrebuințare",
        "deșucheat",
        "divergent",
        "cesionat",
        "dezgolire",
        "divorț",
        "ameţeală",
        "ameţit",
        "andocat",
        "NO TRANSLATION",
        "demoralizare",
        "ajutor de șomaj",
        "NO TRANSLATION",
        "dominant",
        "dominaţie",
        "măgar",
        "mâzgălitură",
        "osândă",
        "osândit",
        "judecata de apoi",
        "îndoială",
        "îndoielnic",
        "îndoielii",
        "duş",
        "aspru",
        "aversă",
        "monotonie",
        "drenaj",
        "dezavantaj",
        "temut",
        "îngrozitor",
        "respingător",
        "mohorât",
        "băut",
        "prostii",
        "trântor",
        "moleşit",
        "secetă",
        "îneca",
        "somnolenţă",
        "corvoadă",
        "beat",
        "beţie",
        "dubios",
        "plictisitor",
        "prost",
        "fictiv",
        "splin",
        "mohorât",
        "Temniță",
        "găgăuță",
        "duplicitate",
        "lipsirea de libertate",
        "praf",
        "pipernicită",
        "moarte",
        "dizenterie",
        "cutremur",
        "trage cu urechea",
        "edict",
        "afemeiat",
        "egotistic",
        "extraordinar",
        "evacua",
        "evacuare",
        "eliminare",
        "evaziv",
        "descărnat",
        "NO TRANSLATION",
        "a face de rusine",
        "jenant",
        "jenă",
        "delapidare",
        "embolie",
        "embroiled",
        "de urgență",
        "enclavă",
        "uzurpare",
        "obstacol",
        "periclita",
        "pe cale de dispariție",
        "endemic",
        "dusman",
        "executare",
        "enigmatic",
        "antipatie",
        "subjuga",
        "înrobit",
        "înrobire",
        "obscur",
        "rețea de sârmă ghimpată",
        "intestine",
        "invidios",
        "epidemie",
        "epilepsie",
        "eradica",
        "eradicarea",
        "şterge",
        "eroziune",
        "greși",
        "rătăcitor",
        "neregulat",
        "erată",
        "eronat",
        "eroare",
        "erupe",
        "erupţie",
        "escalada",
        "se feri",
        "spionaj",
        "înstrăinat",
        "eutanasie",
        "evacua",
        "evacuare",
        "se sustrage",
        "evaziune",
        "evacua",
        "evacuare",
        "rău",
        "exacerba",
        "exacerbare",
        "exigent",
        "exagera",
        "exagerat",
        "examinare",
        "exasperare",
        "excavare",
        "exces",
        "accize",
        "exclus",
        "F? r?",
        "excludere",
        "excremente",
        "chinuitor",
        "scuză",
        "execuţie",
        "călău",
        "epuiza",
        "epuizat",
        "epuizare",
        "NO TRANSLATION",
        "exil",
        "exorcism",
        "expatria",
        "expulza",
        "cheltuieli",
        "cheltuieli",
        "expira",
        "expirat",
        "expletiv",
        "exploda",
        "explozie",
        "exploziv",
        "expuse",
        "expropriere",
        "expulzare",
        "extermina",
        "exterminare",
        "dispărut",
        "a stinge",
        "extrajudiciar",
        "extremitate",
        "fabrica",
        "fabricare",
        "decolorare",
        "excremente",
        "în lipsa",
        "eșec",
        "leșin",
        "necredincios",
        "fals",
        "cădea",
        "greșit",
        "eroare",
        "supus greșelii",
        "cădere",
        "nedezvoltat",
        "falsitate",
        "în mod fals",
        "falsificare",
        "falsifica",
        "falsitate",
        "șovăi",
        "foamete",
        "fanatic",
        "farsă",
        "ridicol",
        "post",
        "gras",
        "fatal",
        "fatalitate",
        "soartă",
        "oboseală",
        "obosite",
        "gras",
        "eroare",
        "defect",
        "cafeniu",
        "frică",
        "fricos",
        "teamă",
        "temându-se",
        "febril",
        "fecale",
        "fecale",
        "taxă",
        "slab",
        "simulat",
        "căzut",
        "infractor",
        "crimă",
        "ferment",
        "feroce",
        "ferocitate",
        "feudă",
        "feudal",
        "feudalism",
        "febril",
        "fiasco",
        "născocire",
        "nestatornic",
        "fictiv",
        "satana",
        "feroce",
        "luptă",
        "luptă",
        "pirat",
        "murdărie",
        "murdar",
        "arme de foc",
        "se potrivește",
        "flasc",
        "flasc",
        "lipsit de viață",
        "flagrant",
        "fulg",
        "clapă",
        "meteorism",
        "face paradă de",
        "defect",
        "purice",
        "NO TRANSLATION",
        "lână",
        "cărnos",
        "tresări",
        "biciui",
        "chix",
        "cambulă",
        "gripă",
        "fluctuaţie",
        "duşman",
        "dejucată",
        "nebunie",
        "prost",
        "prostesc",
        "nebunie",
        "furaj",
        "incursiune",
        "interzis",
        "interzicere",
        "forta",
        "forţat",
        "cu forţa",
        "prevestitor",
        "împiedica",
        "preceda",
        "străin",
        "străin",
        "forewarned",
        "pierdut",
        "pierdute",
        "confiscare",
        "fals",
        "a uita",
        "uitat",
        "deznădăjduit",
        "fără formă",
        "adulter",
        "părăsi",
        "părăsit",
        "fault",
        "fractură",
        "fragil",
        "debilitate",
        "frenetic",
        "fraudă",
        "necinstit",
        "plină",
        "înfricoșa",
        "zdrențuit",
        "ciudat",
        "congelare",
        "frenetică",
        "frenetic",
        "frenezie",
        "toci",
        "frică",
        "speria",
        "înspăimântat",
        "înspăimântător",
        "rece",
        "frivol",
        "degerături",
        "spumă",
        "se încrunta",
        "încruntat",
        "zadarnic",
        "zădărnici",
        "frustrat",
        "frustrare",
        "născoci",
        "fugar",
        "orbecăi",
        "fum",
        "fumans",
        "ciuperca",
        "panică",
        "furios",
        "furor",
        "furie",
        "tam-tam",
        "agitat",
        "zadarnic",
        "inutilitate",
        "gaby",
        "căluș",
        "fiere",
        "spânzurătoare",
        "joc de noroc",
        "jucător",
        "jocuri de noroc",
        "bandă",
        "închisoare",
        "decalaj",
        "gunoi",
        "bătător la ochi",
        "garnitură",
        "tăietură",
        "trăgîndu",
        "NO TRANSLATION",
        "sfrijit",
        "gorobete",
        "geriatrie",
        "scârbos",
        "ghetou",
        "fantomatic",
        "bolboroseală",
        "glacial",
        "orbi",
        "bătător la ochi",
        "curgător",
        "jale",
        "sumbru",
        "încruntat",
        "saturare",
        "lăcomie",
        "gnom",
        "elf",
        "ateu",
        "gonoree",
        "goo",
        "împunge",
        "chei",
        "gorilă",
        "sângerat",
        "bârfă",
        "scoate",
        "gută",
        "guvern",
        "apuca",
        "zgârcit",
        "grătar",
        "răzuită",
        "grații",
        "mormânt",
        "lăcomie",
        "lacom",
        "grenadă",
        "jale",
        "plângere",
        "întrista",
        "dureros",
        "rău",
        "murdărie",
        "tuciuriu",
        "măcinare",
        "hidos",
        "cărunt",
        "geme",
        "NO TRANSLATION",
        "brut",
        "grotesc",
        "împământat",
        "fără temei",
        "hârâit",
        "maraitul",
        "pică",
        "câine-câinește",
        "macabru",
        "aspru",
        "bâzâi",
        "morocănos",
        "gherilă",
        "viclenie",
        "ghilotină",
        "vinovăţie",
        "vinovat",
        "înfățișare",
        "pescăruş",
        "credul",
        "armă",
        "şuvoi",
        "pileală",
        "țigan",
        "hoanghină",
        "tras la față",
        "păros",
        "la jumătatea distanței",
        "halucinaţie",
        "ştreang",
        "șovăitor",
        "coş",
        "hamstring",
        "handicap",
        "agăţat",
        "călău",
        "hărțui",
        "vestitor",
        "călit",
        "duritate",
        "dificultate",
        "prostituată",
        "dăuna",
        "nociv",
        "chinuitor",
        "dezgoli",
        "asprime",
        "hașiș",
        "haşiş",
        "pripit",
        "ură",
        "odios",
        "urând",
        "ură",
        "trufaş",
        "bântui",
        "bântuit",
        "prăpăd",
        "pericol",
        "riscant",
        "ceață",
        "durere de cap",
        "impetuos",
        "auz",
        "din auzite",
        "dric",
        "durere de inimă",
        "arsură",
        "fără inimă",
        "păgân",
        "puternic",
        "toc",
        "spori",
        "atroce",
        "iad",
        "infernal",
        "neajutorat",
        "neajutorare",
        "hemoragie",
        "hemoroizi",
        "erezie",
        "eretic",
        "hermafrodit",
        "heroină",
        "herpes",
        "Herpesvirus",
        "ezitare",
        "ascuns",
        "hidos",
        "împiedicând",
        "împiedicare",
        "hippie",
        "șuierat",
        "sâsâit",
        "lovit",
        "până acum",
        "stup",
        "răguşit",
        "cărunt",
        "farsă",
        "vagabond",
        "porc",
        "gol",
        "holocaust",
        "fără adăpost",
        "dornic de casă",
        "ucigător",
        "omucidere",
        "homosexualitate",
        "capotă",
        "coroiat",
        "huiduială",
        "fara speranta",
        "inutilitate",
        "hoardă",
        "oribil",
        "oribil",
        "oribil",
        "oribil",
        "îngrozit",
        "înfricoșător",
        "groază",
        "orori",
        "ostatic",
        "ostil",
        "ostilități",
        "ostilitate",
        "urla",
        "acces de furie",
        "farsor",
        "umili",
        "umilitor",
        "umilire",
        "bănuială",
        "flămând",
        "vânător",
        "vânătoare",
        "uragan",
        "grăbit",
        "rănit",
        "supărător",
        "doare",
        "hustler",
        "hidră",
        "hidrocefalie",
        "hype",
        "hiperbolă",
        "ipocrizie",
        "ipocrit",
        "ipocrit",
        "isterie",
        "isteric",
        "imbecilitate",
        "idiot",
        "idiot",
        "leneş",
        "idolatrie",
        "ignoranţă",
        "ignorant",
        "ignora",
        "bolnav",
        "ilegal",
        "nelegalitate",
        "ilizibil",
        "nelegitim",
        "ilicit",
        "analfabet",
        "boală",
        "ilogic",
        "amăgire",
        "imitat",
        "imitaţie",
        "imatur",
        "imaturitate",
        "imoral",
        "imoralitate",
        "slăbi",
        "deteriorare",
        "de netrecut",
        "nerăbdare",
        "nerăbdător",
        "pune sub acuzare",
        "punere sub acuzare",
        "împiedica",
        "imperfecţiune",
        "imperfectly",
        "juca rolul",
        "impersonarea",
        "implacabil",
        "implica",
        "nepoliticos",
        "impunere",
        "imposibil",
        "impotenţă",
        "impotent",
        "sechestra",
        "impracticabil",
        "întemnița",
        "întemnițat",
        "pedeapsa cu închisoarea",
        "indecență",
        "imprudent",
        "impur",
        "impuritate",
        "imputare",
        "incapacitate",
        "inaccesibil",
        "inexact",
        "inacțiune",
        "inactivitate",
        "NO TRANSLATION",
        "neadecvat",
        "inadmisibil",
        "găunos",
        "inaplicabil",
        "nepotrivit",
        "neatenţie",
        "abia auzit",
        "incalculabil",
        "incapacitate",
        "încarcerare",
        "in caz",
        "incendiar",
        "tămâia",
        "neîncetat",
        "incest",
        "incestuos",
        "incinerare",
        "incita",
        "neîndurător",
        "incoerent",
        "incompatibil",
        "incompetenţă",
        "incompetent",
        "incompletitudine",
        "de neînţeles",
        "inarmonic",
        "inconsecvent",
        "nechibzuit",
        "incoerență",
        "incomod",
        "incorect",
        "neîncrezător",
        "incriminare",
        "spirit rău",
        "suporta",
        "incurabil",
        "incursiune",
        "indecent",
        "nehotărâre",
        "nehotărât",
        "imposibil de apărat",
        "despăgubi",
        "știrbitură",
        "nedeterminat",
        "inculpa",
        "punere sub acuzare",
        "indiferenţă",
        "nevoiaș",
        "indignat",
        "indignare",
        "indistinct",
        "îndoctrinare",
        "indolent",
        "ineficace",
        "fără rezultat",
        "ineficacitate",
        "ineficace",
        "nepotrivit",
        "stupiditate",
        "inegalitate",
        "inechitabil",
        "inert",
        "de neiertat",
        "NO TRANSLATION",
        "lipsit de experiență",
        "inexplicabil",
        "infam",
        "infamie",
        "infanticid",
        "infantil",
        "infarct",
        "infecta",
        "infecţie",
        "infecțios",
        "inferior",
        "inferioritate",
        "infern",
        "infertilitate",
        "infestare",
        "necredincios",
        "infidelitate",
        "infirma",
        "neputinţă",
        "inflamaţie",
        "umflat",
        "umflare",
        "cauza",
        "cauzare",
        "gripă",
        "informator",
        "încălcare",
        "rar",
        "încălcare",
        "inhiba",
        "inospitalier",
        "inuman",
        "lipsă de omenie",
        "dușmănos",
        "nedreptate",
        "ordin",
        "răni",
        "rănit",
        "vătămător",
        "rănire",
        "nedreptate",
        "locatar",
        "inoperant",
        "nebun",
        "nebunie",
        "nesigur",
        "nesiguranță",
        "insidios",
        "inconsistență",
        "nesemnificativ",
        "insipid",
        "insolent",
        "insolvabilitate",
        "insolvabil",
        "instabilitate",
        "instiga",
        "instigare",
        "insuficienţă",
        "insuficient",
        "insuficient",
        "insultă",
        "insultător",
        "insurgent",
        "insurmontabil",
        "insurecţie",
        "inter",
        "interdicţie",
        "amestec",
        "înhumare",
        "întrerupe",
        "întrerupt",
        "intestat",
        "intimida",
        "intimidare",
        "intolerabil",
        "intoleranţă",
        "intolerant",
        "în stare de ebrietate",
        "intratabil",
        "intrigă",
        "intrus",
        "intruziune",
        "intruziv",
        "a invada",
        "invadator",
        "invalida",
        "invalidare",
        "invaliditate",
        "invazie",
        "involuntar",
        "involuţie",
        "iritat",
        "NO TRANSLATION",
        "fiare de călcat",
        "iraţional",
        "iraţionalitate",
        "ireconciliabil",
        "neregulat",
        "neregularitate",
        "irelevant",
        "ireparabil",
        "iresponsabil",
        "ireverențios",
        "irevocabil",
        "iritabilitate",
        "iritabil",
        "enervant",
        "iritație",
        "izolat",
        "izolare",
        "trăncăni",
        "temniță",
        "jargon",
        "discordant",
        "icter",
        "gelos",
        "gelozie",
        "periclita",
        "primejdie",
        "Ioan",
        "glumă",
        "NO TRANSLATION",
        "harababură",
        "deșeuri",
        "juntă",
        "juvenil",
        "țăran irlandez",
        "lovitură",
        "răpi",
        "ucide",
        "ucidere",
        "zmeu",
        "dangăt",
        "cioturos",
        "greu",
        "laborios",
        "labirint",
        "lipsă",
        "lipsit",
        "lacklustre",
        "încărcat",
        "întârziere",
        "rămâne în urmă",
        "vizuină",
        "plânge",
        "alunecare de teren",
        "fără vlagă",
        "lâncezi",
        "care se stinge",
        "interval",
        "furt",
        "geană",
        "târziu",
        "întârziere",
        "latent",
        "latrine",
        "ridicol",
        "lavă",
        "anarhie",
        "proces",
        "avocat",
        "lax",
        "laxativ",
        "leneş",
        "spărtură",
        "scurgere",
        "permeabil",
        "părăsi",
        "lipitoare",
        "lipitori",
        "NO TRANSLATION",
        "lămâie",
        "lepră",
        "lesbiană",
        "reduce",
        "mai puțin",
        "mortal",
        "letargie",
        "leucemie",
        "taxă",
        "indecent",
        "legătură",
        "mincinos",
        "calomnie",
        "linge",
        "minciună",
        "lipsit de viață",
        "limitat",
        "moale",
        "puf",
        "băutură",
        "apatic",
        "împricinat",
        "se judeca",
        "litigiu",
        "litigios",
        "gunoi",
        "livid",
        "pâine",
        "haimana",
        "NO TRANSLATION",
        "repugna",
        "silă",
        "scârbos",
        "lobbyist",
        "NO TRANSLATION",
        "salcâm",
        "elevat",
        "singurătate",
        "singuratic",
        "singur",
        "loo",
        "război de ţesut",
        "cufundar",
        "ţăcănit",
        "pradă",
        "pierde",
        "pierzând",
        "pierderi",
        "pierdut",
        "intensitate",
        "salon",
        "păduche",
        "inferior",
        "coborâre",
        "cel mai mic",
        "depresiuni",
        "umil",
        "ridicol",
        "exploatările forestiere",
        "umflătură",
        "zgrunțuros",
        "nebunie",
        "nebun",
        "ascunziș",
        "ispitire",
        "sângeriu",
        "pândi",
        "spectatori",
        "luxuriant",
        "dorință",
        "desfrânat",
        "minciună",
        "linșa",
        "buzdugan",
        "nebun",
        "exaspera",
        "nebun",
        "nebunie",
        "mafie",
        "vierme",
        "expedient",
        "boală",
        "indispoziție",
        "malarie",
        "răuvoitor",
        "încălcarea legii",
        "malformaţie",
        "răutate",
        "rău",
        "bârfi",
        "malignitate",
        "maligne",
        "incompetenţă",
        "Mandamus",
        "NO TRANSLATION",
        "calandru",
        "manie",
        "maniac",
        "maniacală",
        "manipula",
        "manipulare",
        "omor prin imprudenţă",
        "gunoi",
        "strica",
        "margine",
        "maro",
        "martingală",
        "martir",
        "martiriu",
        "masochismul",
        "masacru",
        "materialism",
        "materialist",
        "şerpuit",
        "fără înţeles",
        "pojar",
        "se amesteca",
        "mediocru",
        "mediocritate",
        "melancolic",
        "melancolie",
        "busculadă",
        "melodramă",
        "Meltdown",
        "ameninţare",
        "ameninţător",
        "servil",
        "mercenar",
        "nemilos",
        "dezordine",
        "murdar",
        "metastază",
        "metanol",
        "mucegai",
        "miliţie",
        "mimetism",
        "minimaliza",
        "minim",
        "minoritate",
        "NO TRANSLATION",
        "abatere disciplinara",
        "avort",
        "bucluc",
        "răutăcios",
        "neînțelegere",
        "abatere",
        "mizerabil",
        "mizerabil",
        "mizerie",
        "ghinion",
        "greșită",
        "misfortună",
        "interpretare greșită",
        "induce în eroare",
        "derutant",
        "proasta gestionare",
        "nepotrivire",
        "termen impropriu",
        "pune greșit",
        "nepotrivit",
        "denatura",
        "denaturare",
        "a interpretat eronat",
        "dispărut",
        "denaturare",
        "greşeală",
        "greșit",
        "amantă",
        "NO TRANSLATION",
        "înțelege greșit",
        "neînţelegere",
        "folosire greșită",
        "căpușă",
        "gloată",
        "bătaie de joc",
        "batjocoritor",
        "molestare",
        "monocrom",
        "monopolist",
        "muson",
        "monstru",
        "monstruozitate",
        "cu toane",
        "aduce în discuție",
        "morbid",
        "morbiditate",
        "morgă",
        "muribund",
        "imbecil",
        "moronic",
        "bucăţică",
        "muritor",
        "mortalitate",
        "mortificare",
        "morgă",
        "ţânţar",
        "jeli",
        "îndoliat",
        "doliu",
        "noroi",
        "noroi",
        "încâlci",
        "muddled",
        "plin de noroi",
        "manşon",
        "catâr",
        "mămică",
        "molfăi",
        "oreion",
        "crimă",
        "criminal",
        "ucigător",
        "întunecos",
        "NO TRANSLATION",
        "prăfuit",
        "mutantă",
        "desfigurat",
        "mutilare",
        "răzvrătire",
        "NO TRANSLATION",
        "bot",
        "miopie",
        "înșfăca",
        "nadir",
        "NO TRANSLATION",
        "naiv",
        "fără nume",
        "scămoşat",
        "narcotic",
        "neplăcut",
        "obraznic",
        "greaţă",
        "grețos",
        "NO TRANSLATION",
        "necesar",
        "nevoiaș",
        "abject",
        "negare",
        "negativ",
        "neglijare",
        "uitat",
        "neglijând",
        "neglijenţă",
        "neglijent",
        "NO TRANSLATION",
        "negru",
        "nepotism",
        "agitat",
        "de jos",
        "urzica",
        "nevralgie",
        "nevroză",
        "nevrotic",
        "nicotină",
        "negru",
        "coșmar",
        "nihilism",
        "zgomot",
        "zgomotos",
        "NO TRANSLATION",
        "Prostii",
        "fără sens",
        "laţ",
        "nimic",
        "nociv",
        "pacoste",
        "NO TRANSLATION",
        "anula",
        "amorțit",
        "amorţeală",
        "NO TRANSLATION",
        "țărănoi",
        "obez",
        "obezitate",
        "obi",
        "necrolog",
        "necrolog",
        "obiecţie",
        "inacceptabil",
        "obliga",
        "debitor",
        "șterge orice urmă de",
        "obliterate",
        "ștergere",
        "uitare",
        "respingător",
        "obscen",
        "obscenitate",
        "obscuritate",
        "obstacol",
        "încăpăţânat",
        "împiedica",
        "obstrucţie",
        "obstructiv",
        "obtuz",
        "ocult",
        "ciudăţenie",
        "odios",
        "miros",
        "jigni",
        "ofensat",
        "contravenient",
        "delict",
        "ofensator",
        "improvizat",
        "largul mării",
        "căpcăun",
        "olfactiv",
        "oligarhie",
        "augur",
        "de rău augur",
        "omite",
        "oneros",
        "răspundere",
        "se prelinge",
        "opac",
        "de operă",
        "narcotic",
        "înfumurat",
        "opiu",
        "adversar",
        "opune",
        "opus",
        "opoziţie",
        "asupri",
        "asuprire",
        "apăsător",
        "asupritor",
        "Orc",
        "chin",
        "artilerie",
        "orfan",
        "aparent",
        "da afară",
        "proscris",
        "țipăt",
        "latrină",
        "ciudat",
        "haiduc",
        "ultraj",
        "aclamație",
        "arogant",
        "supraîncărca",
        "acoperit de nori",
        "exagera",
        "supradoză",
        "întârziat",
        "supraestimat",
        "revărsare",
        "prea mare",
        "suprasarcină",
        "plătită în plus",
        "copleși",
        "copleșitor",
        "prea scump",
        "supraveghere",
        "răsturna",
        "răsturna",
        "copleși",
        "copleşit",
        "debitului;",
        "oxidare",
        "durere",
        "îndurerat",
        "dureros",
        "dureros de",
        "dureri",
        "paralizie",
        "pandemie",
        "NO TRANSLATION",
        "panică",
        "paralizie",
        "paralizat",
        "paranoia",
        "parazit",
        "NO TRANSLATION",
        "papagal",
        "strângător",
        "partizan",
        "NO TRANSLATION",
        "pasiv",
        "pasivitate",
        "plasture",
        "jalnic",
        "ocrotitoare",
        "NO TRANSLATION",
        "număr mic",
        "cerşetor",
        "pion",
        "răzbunare",
        "plată",
        "particularităţile",
        "pieton",
        "penal",
        "penalizare",
        "penetrație",
        "penitenciar",
        "pierzanie",
        "pune în pericol",
        "periculos",
        "pieri",
        "perisabil",
        "dispărut",
        "pieritor",
        "sperjur",
        "pernicios",
        "autor",
        "perpetuare",
        "nedumerit",
        "nedumerire",
        "persecuta",
        "persecuţie",
        "perturbație",
        "tuse convulsivă",
        "îndărătnic",
        "perversiune",
        "perverti",
        "pervertit",
        "pesimism",
        "pesimist",
        "dăunător",
        "molimă",
        "animal de companie",
        "mic",
        "fantomă",
        "indiferenţă",
        "fals",
        "picheta",
        "pichetare",
        "murătură",
        "porc",
        "porumbel",
        "piloți",
        "prădare",
        "proxenet",
        "cos",
        "pin",
        "pinion",
        "pichet",
        "piraterie",
        "pirat",
        "pistol",
        "capcană",
        "plagiat",
        "ciumă",
        "reclamant",
        "placate",
        "jucător",
        "motiv",
        "stare",
        "mergând cu greu",
        "fir cu plumb",
        "jaf",
        "plonjare",
        "pneumonie",
        "braconaj",
        "fără sens",
        "otravă",
        "otrăvit",
        "otrăvire",
        "otrăvitor",
        "împungere",
        "polemică",
        "poliomielita",
        "polua",
        "poluare",
        "poligamie",
        "pompă",
        "pompos",
        "plicticos",
        "slab",
        "pop",
        "porc spinos",
        "porno",
        "porno",
        "pornografic",
        "pornografie",
        "pune",
        "posedat",
        "deţinere",
        "postum",
        "amânare",
        "livră",
        "sărăcie",
        "fără putere",
        "glumă",
        "precar",
        "incinta",
        "răpitor",
        "situație neplăcută",
        "sarcină",
        "prejudecată",
        "prejudiciată",
        "prejudiciabil",
        "premeditat",
        "presiune",
        "încrezut",
        "pretinde",
        "pretins",
        "pretinzând că",
        "prefăcătorie",
        "pretentiile",
        "preventiv",
        "pradă",
        "înțepătură",
        "înţepător",
        "închisoare",
        "prizonier",
        "latrină",
        "problemă",
        "amâna",
        "procrastinare",
        "profan",
        "profanare",
        "abundenţă",
        "interzise",
        "interdicţie",
        "prelungi",
        "promiscuu",
        "propagandă",
        "urmări în justiție",
        "urmarire penala",
        "prostituată",
        "prostituţie",
        "provocare",
        "provocator",
        "desface",
        "băgăcios",
        "psihoză",
        "publicist",
        "durduliu",
        "lovi cu pumnul",
        "iute",
        "pedepsi",
        "pedepsit",
        "pedepsirea",
        "pedeapsă",
        "represiv",
        "purgatoriu",
        "epurare",
        "puroi",
        "vraci",
        "mlaştină",
        "prepeliţă",
        "dilemă",
        "ceartă",
        "înăbuși",
        "înăbuși",
        "discutabil",
        "mercur",
        "părăsi",
        "freamăt",
        "tremurător",
        "chestionare",
        "gloată",
        "turbat",
        "turbare",
        "portbagaj",
        "rachetă",
        "radiație",
        "radioactiv",
        "radon",
        "furie",
        "furios",
        "peticărie",
        "raid",
        "șină",
        "Berbec",
        "incoerent",
        "ieşire violentă",
        "rânced",
        "răscumpărare",
        "viol",
        "raptors",
        "canalie",
        "eczemă",
        "şobolan",
        "evaluare",
        "răguşit",
        "vorace",
        "aiureală",
        "reacţionar",
        "spate",
        "rebel",
        "mustrare",
        "respinge",
        "recalcitrant",
        "recesiune",
        "recidivei",
        "nesăbuit",
        "nepăsare",
        "redundant",
        "reflux",
        "refractar",
        "refuz",
        "refuza",
        "refuzat",
        "regres",
        "regresiune",
        "regret",
        "regretabil",
        "regretat",
        "regretând",
        "reglementare",
        "frâu",
        "respinge",
        "respins",
        "respingere",
        "respinge",
        "recidiva",
        "retrogradare",
        "renunța",
        "șovăitor",
        "arest preventiv",
        "remediere",
        "neglijent",
        "remuşcare",
        "îndepărtare",
        "elimina",
        "NO TRANSLATION",
        "NO TRANSLATION",
        "renegat",
        "renunța la",
        "renunţare",
        "NO TRANSLATION",
        "respingător",
        "respingător",
        "reprima",
        "represiune",
        "mustrare",
        "retipărire",
        "represalie",
        "reproș",
        "republică",
        "repudiere",
        "repulsie",
        "anula",
        "anulare",
        "displace",
        "indignat",
        "resentiment",
        "demisiona",
        "demisie",
        "demisionat",
        "a rezista",
        "rezistenţă",
        "rezistent",
        "rezistente",
        "reține",
        "restrânge",
        "restricţie",
        "restrictiv",
        "răzbuna",
        "represalii",
        "de represalii",
        "întârzia",
        "întârziere",
        "reticent",
        "replică",
        "retrage",
        "retragere",
        "fortificație",
        "pedeapsă",
        "retrograd",
        "răzbunare",
        "inversare",
        "anulare",
        "revoca",
        "revoltă",
        "revoltător",
        "revolver",
        "revulsiune",
        "reumatism",
        "rahitic",
        "ciuruit",
        "ridicol",
        "ridicol",
        "frecvent",
        "puşcă",
        "ruptură",
        "rigid",
        "rigiditate",
        "rigoare",
        "riguros",
        "clopotar",
        "răscoală",
        "turbulent",
        "risc",
        "riscant",
        "rivalitate",
        "jefui",
        "jefuitor",
        "jaf",
        "derbedeu",
        "găgăuță",
        "putrezi",
        "descompunere",
        "rugozitate",
        "NO TRANSLATION",
        "rând",
        "bătăuș",
        "gunoi",
        "moloz",
        "rue",
        "zburli",
        "robust",
        "ruina",
        "ruinat",
        "ruinător",
        "zvon",
        "fugi",
        "ruptură",
        "NO TRANSLATION",
        "rugini",
        "ruginit",
        "nemilos",
        "NO TRANSLATION",
        "sabotaj",
        "sacrificii",
        "trist",
        "tristeţe",
        "scădere a prețului",
        "sevă",
        "sarcasm",
        "sarcom",
        "sardonic",
        "satanic",
        "saturate",
        "sălbatic",
        "sălbăticie",
        "râie",
        "schelă",
        "scalpel",
        "solzos",
        "scandal",
        "scandalos",
        "rar",
        "ţap ispăşitor",
        "cicatrice",
        "rar",
        "abia",
        "raritate",
        "a speria",
        "gunoier",
        "sistem",
        "schismă",
        "schizofrenie",
        "sciatică",
        "sfida",
        "certa",
        "ciondăneală",
        "arzător",
        "dispreţ",
        "scorpion",
        "scotch",
        "ticălos",
        "flagel",
        "urcare",
        "scrapie",
        "ţipăt",
        "țipând",
        "ţipăt",
        "înșurubate",
        "îmbulzeală",
        "tufărie",
        "scruta",
        "control",
        "gunoi",
        "cauteriza",
        "secesiune",
        "retras",
        "NO TRANSLATION",
        "secreţie",
        "secretor",
        "sectar",
        "răzvrătire",
        "seduce",
        "seducţie",
        "separa",
        "segregate",
        "confisca",
        "egoist",
        "egoism",
        "senil",
        "fără simțire",
        "propoziție",
        "separatist",
        "sepsis",
        "septic",
        "sechestrare",
        "senin",
        "şarpe",
        "servitor",
        "servi",
        "servil",
        "servitute",
        "regres",
        "reteza",
        "canalizare",
        "canalizare",
        "ponosit",
        "baracă",
        "toartă",
        "umbrit",
        "zguduire",
        "tremurător",
        "fals",
        "abator",
        "rușine",
        "ruşinos",
        "nerușinat",
        "Shanghai",
        "rechin",
        "sfărâma",
        "spulberat",
        "vărsa",
        "coajă",
        "shelved",
        "naufragiu",
        "rahat",
        "fior",
        "şoc",
        "calitate inferioara",
        "trage",
        "filmare",
        "furt din magazine",
        "deficit",
        "neajuns",
        "lovitură",
        "îmbrânci",
        "arătos",
        "ţipăt",
        "strident",
        "se contracta",
        "coșcovit",
        "fior",
        "se feri",
        "bolnav",
        "grețos",
        "bolnăvicios",
        "boală",
        "prost",
        "NO TRANSLATION",
        "păcătos",
        "sinistru",
        "păcătos",
        "păcătuind",
        "sirenă",
        "surioară",
        "sceptic",
        "vag",
        "oblică",
        "derapa",
        "ocolire",
        "încăierare",
        "moale",
        "zgură",
        "șlem",
        "calomnie",
        "calomnios",
        "palmă",
        "măcel",
        "abator",
        "abatorizare",
        "sclav",
        "robie",
        "ucide",
        "criminal",
        "lapoviţă",
        "noroios",
        "se furişa",
        "alunecare",
        "NO TRANSLATION",
        "desfundat",
        "Lene",
        "nepriceput",
        "băltoacă",
        "încetineală",
        "nămol",
        "melc",
        "lent",
        "mahala",
        "criză",
        "legato",
        "noroi",
        "curvă",
        "viclean",
        "jart",
        "mic",
        "lovitura",
        "distrus",
        "brumă",
        "miros",
        "mirositor",
        "rânjet",
        "lovi",
        "fumător",
        "sufoca",
        "murdări",
        "elegant",
        "escamota",
        "contrabandist",
        "contrabandă",
        "negru de fum",
        "inconvenient",
        "snags",
        "şarpe",
        "cursă",
        "mârâit",
        "snarling",
        "a strecura",
        "ascuns",
        "insinuare",
        "strănut",
        "snide",
        "snob",
        "scufunda",
        "NO TRANSLATION",
        "socialist",
        "sol",
        "terfelit",
        "somatic",
        "sumbru",
        "funingine",
        "vrăjitorie",
        "sordid",
        "inflamat",
        "dovedește",
        "durere",
        "întristare",
        "trist",
        "NO TRANSLATION",
        "fără inimă",
        "suflet pereche",
        "acru",
        "chelfăni",
        "spasm",
        "ghetră",
        "suliţă",
        "părticică",
        "spectru",
        "spectral",
        "speculație",
        "a petrecut",
        "fată bătrână",
        "ciudă",
        "duşmănos",
        "șindrilă",
        "Despică",
        "despicare",
        "strica",
        "jefuitor",
        "vorbit",
        "burete",
        "stafie",
        "entorsă",
        "sindrofie",
        "spiriduș",
        "contrafăcut",
        "vijelie",
        "persoană care stă ghemuită",
        "greu de mulțumit",
        "lipăit",
        "se agita",
        "înjunghia",
        "amețitor",
        "stagnant",
        "pată",
        "stătut",
        "tulpină",
        "standoff",
        "oprire",
        "holbat",
        "puternic",
        "tresărire",
        "foame",
        "înfometat",
        "flămând",
        "staționar",
        "portativ",
        "fura",
        "furat",
        "ascuns",
        "stereotip",
        "stereotipat",
        "steril",
        "sterilitate",
        "pupa",
        "rigid",
        "rigiditate",
        "înăbuși",
        "asfixiat",
        "stigmat",
        "născut mort",
        "ustura",
        "usturător",
        "zgârcit",
        "putoare",
        "împuţit",
        "preget",
        "stocurile",
        "furat",
        "piatră",
        "cu pietre",
        "scaune",
        "oprire",
        "furtună",
        "furtunos",
        "încordat",
        "strâmtori",
        "naufragiat",
        "străin",
        "sugruma",
        "rătăcit",
        "stres",
        "ceartă",
        "grevă",
        "bandă",
        "dunga",
        "dezbrăcat",
        "accident vascular cerebral",
        "lupta",
        "flaminaj",
        "neventilat",
        "poticnire",
        "uimit",
        "pipernicit",
        "prost",
        "prostie",
        "stupoare",
        "urcior",
        "supune",
        "subiect",
        "supuse",
        "supunere",
        "subjugare",
        "subordonat",
        "citaţie",
        "surpare",
        "subvenţie",
        "subzista",
        "scădea",
        "subversiune",
        "subversiv",
        "răsturna",
        "sucomba",
        "a suge",
        "fraier",
        "a da in judecata",
        "suferi",
        "sufferer",
        "suferinţă",
        "sufocant",
        "sufocare",
        "suicidară",
        "sinucidere",
        "trist",
        "citație",
        "scufundat",
        "superficial",
        "de prisos",
        "superstiţios",
        "suprima",
        "suprimare",
        "suprataxă",
        "posac",
        "predare",
        "capitulant",
        "susceptibil",
        "suspect",
        "suspensie",
        "suspiciune",
        "suspicios",
        "tampon",
        "mlaştină",
        "mlăştinos",
        "zvastică",
        "umflătură",
        "înghiţitură",
        "porcine",
        "umflat",
        "simptom",
        "sincopă",
        "tabu",
        "altera",
        "NO TRANSLATION",
        "încurcat",
        "încetineală",
        "tardiv",
        "tarifar",
        "murdări",
        "zăbovi",
        "insipid",
        "batjocură",
        "impozit",
        "şicana",
        "destrămare",
        "plictisitor",
        "NO TRANSLATION",
        "furtună",
        "ispită",
        "casă închiriată",
        "Terminal",
        "terminare",
        "termită",
        "teribil",
        "teroare",
        "terorism",
        "terorist",
        "teroriza",
        "tetanic",
        "pripon",
        "furt",
        "teismului",
        "teocratic",
        "hoţ",
        "însetat",
        "ghimpe",
        "spinos",
        "nechibzuit",
        "chelfăni",
        "amenințare",
        "a ameninta",
        "amenințător",
        "treiera",
        "zvâcnire",
        "regulator",
        "asasin",
        "tronc",
        "fulminant",
        "contracara",
        "tiff",
        "timid",
        "timiditate",
        "pilit",
        "tiradă",
        "obosit",
        "oboseală",
        "obositor",
        "pițigoi",
        "lingău",
        "tutun",
        "toaletă",
        "mreajă",
        "tolera",
        "durere de dinţi",
        "chin",
        "rupt",
        "torpilă",
        "torid",
        "delictuală",
        "tortionara",
        "tortura",
        "atins",
        "sensibil",
        "greu",
        "toxic",
        "toxină",
        "tragedie",
        "tragic",
        "trădător",
        "trop",
        "transă",
        "transgresiune",
        "găteală",
        "capcane",
        "Gunoi",
        "fără valoare",
        "traumatic",
        "NO TRANSLATION",
        "parodie",
        "perfid",
        "trădare",
        "trădare",
        "tremurând",
        "tremur",
        "trepidație",
        "fărădelege",
        "restriște",
        "tribunal",
        "truc",
        "șmecherie",
        "fleac",
        "declanșare",
        "revenire",
        "supărător",
        "trompeta",
        "rostogoli",
        "tumoare",
        "tumoare",
        "tumult",
        "tumultuos",
        "turbulenţă",
        "turbulent",
        "tumult",
        "TIC nervos",
        "taifun",
        "tiranic",
        "tiranie",
        "tiran",
        "urâţenie",
        "urât",
        "ulcer",
        "ulterior",
        "ultimatum",
        "incapabil",
        "inacceptabil",
        "inexplicabil",
        "neaprobată",
        "neatasat",
        "irealizabil",
        "neatrăgător",
        "neautorizat",
        "inevitabil",
        "inconstient",
        "insuportabil",
        "necredinţă",
        "necrezut",
        "nenăscut",
        "straniu",
        "nepăsătoare",
        "incert",
        "egal",
        "necurat",
        "incomod",
        "oneroase",
        "inconştient",
        "neconstituțional",
        "necontrolabil",
        "necontrolată",
        "nehotărât",
        "subminat",
        "prost plătite",
        "mic de statură",
        "indezirabil",
        "nedorit",
        "Anula",
        "nelinişte",
        "neliniștit",
        "necultivat",
        "şomerii",
        "inegal",
        "inegal",
        "inexplicabilă",
        "nedrept",
        "nedreptate",
        "necredincios",
        "nefavorabil",
        "neterminat",
        "neiertat",
        "nefericit",
        "neprietenos",
        "neîmplinit",
        "nemobilata",
        "nelegiuit",
        "nerecunoscător",
        "nefericire",
        "nefericit",
        "nesănătos",
        "nesfânt",
        "neimportant",
        "neimpresionat",
        "neamenajat",
        "neinformat",
        "neinițiat",
        "neinspirat",
        "ininteligibil",
        "fara intentie",
        "dezinteresați",
        "neinteresant",
        "nedrept",
        "nejustificabil",
        "nejustificat",
        "aspru",
        "necunoscut",
        "ilegal",
        "fără licență",
        "ghinionist",
        "refractar",
        "nefiresc",
        "neoficial",
        "neplătit",
        "neplăcut",
        "nepopular",
        "imprevizibil",
        "nepregătit",
        "neproductiv",
        "neprofitabil",
        "neprotejat",
        "nepublicat",
        "nedemn de încredere",
        "neîmpărtășit",
        "nesupus",
        "nesigur",
        "nesatisfăcător",
        "nemulțumit de",
        "grețos",
        "lipsit de scrupule",
        "nelocuit",
        "dizgrațios",
        "nesofisticat",
        "negrăit",
        "instabil",
        "fără succes",
        "nepotrivit",
        "unsung",
        "neacceptat",
        "nesustenabilă",
        "unsympathetic",
        "sireap",
        "de neconceput",
        "de necrezut",
        "neîngrijit",
        "înainte de vreme",
        "fără titlu",
        "nespus",
        "obraznic",
        "neinstruit",
        "neadevărat",
        "neserios",
        "negarantat",
        "nespălat",
        "nepoftit",
        "bolnav",
        "refuzul",
        "imprudent",
        "neștiutor",
        "nevrednic",
        "neînduplecat",
        "răsturnare",
        "răscoală",
        "vacarm",
        "deranjat",
        "pici",
        "urgent",
        "inutil",
        "uzurpa",
        "uzurpat",
        "camătă",
        "post vacant",
        "vacuous",
        "vag",
        "imprecizie",
        "vainly",
        "vampir",
        "dispărut",
        "vanitate",
        "varicela",
        "varicoasă",
        "vegetativ",
        "vehement",
        "vendetă",
        "răzbunare",
        "răzbunător",
        "venin",
        "veninos",
        "limbuție",
        "mărgini",
        "paraziţi",
        "impotriva",
        "amețeală",
        "veto",
        "viciu",
        "vicios",
        "victimă",
        "victimizat",
        "ticălos",
        "mizerabil",
        "răzbunător",
        "încălcare",
        "violenţă",
        "violent",
        "violent",
        "viperă",
        "virulenţă",
        "virus",
        "vizită",
        "vulpe",
        "volatilitate",
        "vulcan",
        "vărsături",
        "Voodoo",
        "vulgar",
        "vulgaritate",
        "vulnerabilitate",
        "vultur",
        "vafelă",
        "boci",
        "aștepta",
        "bălăci",
        "NO TRANSLATION",
        "declin",
        "doresc",
        "război",
        "director",
        "articole",
        "război",
        "belicos",
        "a avertiza",
        "urzeală",
        "warped",
        "neg",
        "deşeuri",
        "pierdut",
        "risipitor",
        "irosirea",
        "apos",
        "șovăi",
        "slăbit",
        "slab",
        "slăbiciune",
        "purta",
        "obosit",
        "oboseală",
        "obosit",
        "buruieni",
        "plânge",
        "ciudat",
        "weirdo",
        "NO TRANSLATION",
        "umbla după femei",
        "lovi cu putere",
        "capriciu",
        "se văita",
        "bici",
        "vârtej de vânt",
        "whisky",
        "curvă",
        "rău",
        "răutate",
        "sălbatic",
        "pisică sălbatică",
        "Foc salbatic",
        "intenționat",
        "wimp",
        "Wimpy",
        "tresărire",
        "vrăjitoare",
        "vrăjitorie",
        "retrage",
        "veșteji",
        "ofilit",
        "Vai",
        "întristător",
        "teribil",
        "cuvinte",
        "vierme",
        "uzat",
        "îngrijorat",
        "face griji",
        "îngrijorătoare",
        "mai rau",
        "agravarea",
        "lipsit de valoare",
        "răni",
        "wrangling",
        "mânie",
        "se răzbuna",
        "distruge",
        "naufragiat",
        "cheie",
        "lupte libere",
        "nenorocit",
        "mizerabil",
        "gresit",
        "faptă rea",
        "nedrept",
        "în mod greșit",
        "lucrat",
        "crispat",
        "xenofobie",
        "căscat",
        "căscat",
        "strigăt",
        "galben",
        "scheunat",
        "zip",
    ]
)

_ambivalent = set(
    [
        "abundenţă",
        "armat",
        "balsam",
        "lăuda",
        "turbulent",
        "şoarece de bibliotecă",
        "dolar",
        "celebritate",
        "Fermecat",
        "eludare",
        "complicitate",
        "mărturisi",
        "viclean",
        "dependent",
        "divers",
        "domina",
        "fără sfârşit",
        "impune",
        "erotic",
        "evadare",
        "sentiment",
        "flirt",
        "grindină",
        "hedonism",
        "cel mai inalt",
        "umil",
        "imediat",
        "imobil",
        "sursa de venit",
        "infiltrare",
        "influență",
        "intens",
        "interminabil",
        "intervenţie",
        "dantelă",
        "liberal",
        "Lord",
        "matern",
        "moaşă",
        "mamă",
        "halbă",
        "notorietate",
        "omnipotență",
        "izbucnire",
        "remarcabil",
        "paradă",
        "parafraza",
        "petrol",
        "prezentare",
        "risipitor",
        "citat",
        "rave",
        "regresiv",
        "reaprinde",
        "rămășițe",
        "pensionare",
        "reînvia",
        "revoluţie",
        "sperietoare",
        "izolare",
        "senzual",
        "spectacol",
        "coloană vertebrală",
        "veritabil",
        "suculent",
        "superstiție",
        "supremaţie",
        "surround,",
        "sinonim",
        "tantalic",
        "adolescenţi",
        "trata",
        "neînvins",
        "neînfrânat",
        "neașteptat",
        "de neimaginat",
        "dezlega",
        "în sus",
        "vot",
        "greutate",
        "dorință",
    ]
)
